@@ -18,9 +18,9 @@
       \endverbatim
   *
   *
-  * Multiply image magnitude of Vista file 'image.v' by a factor 10:
+  * Multiply image magnitude of Nifti file 'image.nii' by a factor 10:
   *   \verbatim
-       micalc -if1 image.v -op '*' -in2 10 -of image.v
+       micalc -if1 image.nii -op '*' -in2 10 -of image.nii
       \endverbatim
   *
   *
@@ -65,7 +65,7 @@ void usage(const Protocol& prot) {
   FilterFactory filter;
   STD_cout << "micalc:  Performs basic mathematics with data sets" << STD_endl;
   STD_cout << "         File formats are automatically identified by their file extension." << STD_endl;
-  STD_cout << "Usage:" << STD_endl;
+  STD_cout << "micalc can be used in one of the following modes:" << STD_endl;
   STD_cout << "  Binary operation with data sets and/or scalar numbers:" << STD_endl;
   STD_cout << "       micalc [-if1 <input-file1> | -in1 <input-number1>] -op <operation(+,-,*,/,lcorr,kcorr)> [-if2 <input-file2> | -in2 <input-number1>] -of <output-file>" << STD_endl;
   STD_cout << "  Accumulation of one data set:" << STD_endl;
@@ -75,13 +75,14 @@ void usage(const Protocol& prot) {
   STD_cout << "  Statistics of one data set:" << STD_endl;
   STD_cout << "       micalc -if <input-file> [-mean <time-mean-file>] [-stdev <time-stdev-file>] [-fluct <relative-time-stdev-file>] [-tcourse <average time course of all voxels>] [-hist <histogram> -histmin <minval> -histmax <maxval> -histslots <numofslots> -rightstairs -histfract]" << STD_endl;
   STD_cout << "Extra options:" << STD_endl;
-  STD_cout << "\t-mask <Mask for data>" << STD_endl;
+  STD_cout << "\t-mask <Binary mask file: voxels with zeroes are discarded>" << STD_endl;
+  STD_cout << "\t-weightmask <Multiply input file(s) with this file>" << STD_endl;
   STD_cout << "File read options:" << STD_endl;
   STD_cout << prot.get_cmdline_usage("\t");
   STD_cout << ropts.get_cmdline_usage("\t");
   STD_cout << "File write options:" << STD_endl;
   STD_cout << wopts.get_cmdline_usage("\t");
-  STD_cout << "Filters applied to input files:" << STD_endl;
+  STD_cout << "Filters applied to input file(s):" << STD_endl;
   STD_cout << filter.get_cmdline_usage("\t");
   STD_cout << "Other options:" << STD_endl;
   STD_cout << "\t" << LogBase::get_usage() << STD_endl;
@@ -91,6 +92,31 @@ void usage(const Protocol& prot) {
 }
 
 
+bool read_infile(const STD_string& filename, Data<float,4>& data, const FileReadOpts& ropts, Protocol& prot, const FilterChain& filterchain, const Data<float,4>& weightmaskdata) {
+  Log<OdinData> odinlog("micalc","read_infile");
+
+  Range all=Range::all();
+
+  Data<float,4> datain;
+
+  if(datain.autoread(filename,ropts,&prot)<0) return false;
+  if(!filterchain.apply(prot,datain)) return false;
+  data.resize(datain.shape());
+
+  if(weightmaskdata.size()) {
+    if( weightmaskdata.extent(0) && same_shape(data, weightmaskdata, TinyVector<int,4>(0,1,1,1) ) ) {
+      for(int irep=0; irep<data.extent(0); irep++) data(irep,all,all,all)=weightmaskdata(0,all,all,all)*datain(irep,all,all,all);
+    } else {
+      ODINLOG(odinlog,errorLog) << "Shape mismatch:  datashape/weightmaskshape=" << data.shape() << "/" << weightmaskdata.shape() << STD_endl;
+      return false;
+    }
+  } else {
+    data=datain; // In case storage order is non-default
+  }
+  return true;
+}
+
+
 int main(int argc, char* argv[]) {
   LogBase::set_log_levels(argc,argv);
 
@@ -115,6 +141,7 @@ int main(int argc, char* argv[]) {
   STD_string infile2;
   STD_string outfile;
   STD_string maskfile;
+  STD_string weightmaskfile;
 
   float innumber1=0.0;
   float innumber2=0.0;
@@ -144,6 +171,7 @@ int main(int argc, char* argv[]) {
   if(getCommandlineOption(argc,argv,"-of",optval,ODIN_MAXCHAR)) {outfile=optval; offlag=true;}
 
   if(getCommandlineOption(argc,argv,"-mask",optval,ODIN_MAXCHAR)) {maskfile=optval;}
+  if(getCommandlineOption(argc,argv,"-weightmask",optval,ODIN_MAXCHAR)) {weightmaskfile=optval;}
 
   STD_string histfile;
   if(getCommandlineOption(argc,argv,"-hist",optval,ODIN_MAXCHAR)) histfile=optval;
@@ -193,20 +221,18 @@ int main(int argc, char* argv[]) {
 
   Data<float,4> data1;
   Data<float,4> data2;
-  Data<float,4> datain;
+
+  Data<float,4> weightmaskdata;
+  if(weightmaskfile!="") {
+    if(weightmaskdata.autoread(weightmaskfile,ropts)<0) return -1;
+  }
 
   if(infile1!="") {
-    if(datain.autoread(infile1,ropts,&prot)<0) return -1;
-    if(!filterchain.apply(prot,datain)) return -1;
-    data1.resize(datain.shape());
-    data1=datain; // In case storage order is non-default
+    if(!read_infile(infile1, data1, ropts, prot, filterchain, weightmaskdata)) return -1;
   }
 
   if(binaryop && infile2!="") {
-    if(datain.autoread(infile2,ropts,&prot)<0) return -1;
-    if(!filterchain.apply(prot,datain)) return -1;
-    data2.resize(datain.shape());
-    data2=datain; // In case storage order is non-default
+    if(!read_infile(infile2, data2, ropts, prot, filterchain, weightmaskdata)) return -1;
   }
 
   TinyVector<int,4> outshape;
@@ -217,11 +243,8 @@ int main(int argc, char* argv[]) {
     bool has_shape1=sum(data1.shape());
     bool has_shape2=sum(data2.shape());
 
-
     if( has_shape1 && has_shape2 && !same_shape(data1,data2) ) {
-      ODINLOG(odinlog,errorLog) << "shape mismatch:" << STD_endl;
-      ODINLOG(odinlog,errorLog) << "data1.shape()=" << data1.shape() << STD_endl;
-      ODINLOG(odinlog,errorLog) << "data2.shape()=" << data2.shape() << STD_endl;
+      ODINLOG(odinlog,errorLog) << "Shape mismatch:  data1shape/data2shape=" << data1.shape() << "/" << data2.shape() << STD_endl;
       return -1;
     } else outshape=data1.shape();
 
@@ -247,13 +270,8 @@ int main(int argc, char* argv[]) {
   Data<float,4> maskdata;
   Data<float,4> inmaskdata;
   if(maskfile!="") {
-    if(inmaskdata.autoread(maskfile,ropts,&prot)<0) return -1;
-    TinyVector<int,4> datashape=data1.shape(); datashape(0)=1;
-    TinyVector<int,4> maskshape=inmaskdata.shape(); maskshape(0)=1;
-    if(datashape!=maskshape) {
-      ODINLOG(odinlog,errorLog) << "Shape mismatch:  datashape/maskshape" << datashape << "/" << maskshape << STD_endl;
-      return -1;
-    } else {
+    if(inmaskdata.autoread(maskfile,ropts)<0) return -1;
+    if( inmaskdata.extent(0) && same_shape(data1, inmaskdata, TinyVector<int,4>(0,1,1,1) ) ) {
       maskdata.resize(data1.shape());
       maskdata=0.0;
       for(int i=0; i<data1.numElements(); i++) {
@@ -262,6 +280,9 @@ int main(int argc, char* argv[]) {
         if(inmaskdata(maskindex)>0.0) maskdata(index)=1.0;
       }
       maskptr=&maskdata;
+    } else {
+      ODINLOG(odinlog,errorLog) << "Shape mismatch:  datashape/maskshape=" << data1.shape() << "/" << inmaskdata.shape() << STD_endl;
+      return -1;
     }
   }
 
@@ -451,7 +472,11 @@ int main(int argc, char* argv[]) {
           }
         }
       }
-      tcourseresult/=float(tcoursepts);
+      if(weightmaskdata.size()) {
+        tcourseresult/=sum(weightmaskdata(0,all,all,all));
+      } else {
+        tcourseresult/=float(tcoursepts);
+      }
       if(meanfile!="")  if(meanresult.autowrite(meanfile,wopts,&prot)<0) return -1;
       if(fluctfile!="") if(fluctresult.autowrite(fluctfile,wopts,&prot)<0) return -1;
       if(stdevfile!="") if(stdevresult.autowrite(stdevfile,wopts,&prot)<0) return -1;
