@@ -18,20 +18,12 @@
   *   \verbatim
        miconv -nx 256 -ny 256 -rf short 2dseq image.dcm
       \endverbatim
-  *
-  *
-  * Extracting the data from the 2nd slice (index 1) of Vista file 'image.v' and store it in
-  * new Vista file 'slice1.v':
-  *   \verbatim
-       miconv -srange 1 image.v slice1.v
-      \endverbatim
   */
 
 struct MiConvOpts : JcampDxBlock {
 
   JDXstring protfile;
   JDXstring parlist;
-  JDXbool non_verbose;
 
   MiConvOpts() {
 
@@ -40,9 +32,6 @@ struct MiConvOpts : JcampDxBlock {
 
     parlist.set_cmdline_option("l").set_description("Lists space-separated set of protocol parameters and exits. Use '-l help' to get a list of possible parameters and '-l all' to list all parameters. The parameter 'output-file' must be omitted when using this option.");
     append_member(parlist,"parlist");
-
-    non_verbose.set_cmdline_option("nv").set_description("be less verbose, show progress in percent only");
-    append_member(non_verbose,"non_verbose");
   }
 
 };
@@ -149,13 +138,9 @@ int main(int argc, char* argv[]) {
   // Read data
   ropts.parse_cmdline_options(argc,argv);
 
-  int readresult;
-  if(mopts.non_verbose){
-    ProgressDisplayConsole display;
-    ProgressMeter mProgress(display);
-    readresult=FileIO::autoread(pdmap_in, infile, ropts, prot_template,&mProgress);
-  }
-  else readresult=FileIO::autoread(pdmap_in, infile, ropts, prot_template);
+  ProgressDisplayConsole display;
+  ProgressMeter progmeter(display);
+  int readresult=FileIO::autoread(pdmap_in, infile, ropts, prot_template,&progmeter);
 
   if(readresult<0) {
     ODINLOG(odinlog,errorLog) << "autoread failed" << STD_endl;
