@@ -27,8 +27,10 @@ struct FmriData {
   Data<float,4> mask;
   Data<float,4> pmap;
   Data<float,4> zmap;
+  Data<float,4> smap;
   Data<float,1> designdata;
   bool has_mask;
+  Protocol protcopy; // writable copy
 };
 
 /////////////////////////////////////////////////////////////////
@@ -48,7 +50,7 @@ MiViewFmri::MiViewFmri() {
   maskfile.set_parmode(hidden).set_cmdline_option("fmask").set_description("fMRI mask file");
   append_member(maskfile,"maskfile");
 
-  bonferr=true;
+  bonferr=false;
   bonferr.set_cmdline_option("bonferr").set_description("Use Bonferroni correction");
   append_member(bonferr,"Bonferroni Correction");
 
@@ -96,11 +98,14 @@ MiViewFmri::MiViewFmri() {
   sigcourse.set_description("fMRI signal change time course");
   append_member(sigcourse,"Relative fMRI Timecourse");
 
-  dumptcourse.set_parmode(hidden).set_cmdline_option("fcourse").set_description("Dump relative fMRI time course to this file");
+  dumptcourse.set_parmode(hidden).set_cmdline_option("scourse").set_description("Dump relative fMRI signal change time course to this file");
   append_member(dumptcourse,"dumptcourse");
 
   dumpzmap.set_parmode(hidden).set_cmdline_option("zmap").set_description("Dump z-score map to this file");
   append_member(dumpzmap,"dumpzmap");
+
+  dumpsmap.set_parmode(hidden).set_cmdline_option("smap").set_description("Dump map of relative fMRI signal change to this file");
+  append_member(dumpsmap,"dumpsmap");
 }
 
 
@@ -113,15 +118,14 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
   Log<MiViewComp> odinlog("MiViewFmri","init");
   Range all=Range::all();
 
-  Protocol protcopy(prot); // writable copy
 
   if(fmrifile=="") return false;
   ODINLOG(odinlog,infoLog) << "Loading fMRI data ..." << STD_endl;
-  if(data->fmri.autoread(fmrifile,ropts,&protcopy)<=0) {
+  if(data->fmri.autoread(fmrifile,ropts,&(data->protcopy))<=0) {
     ODINLOG(odinlog,errorLog) << "Unable to load fmrifile " << fmrifile << STD_endl;
     return false;
   }
-  if(!filterchain.apply(protcopy, data->fmri)) return false;
+  if(!filterchain.apply(data->protcopy, data->fmri)) return false;
 
   // read and parse design file
   if(designfile=="") return false;
@@ -142,7 +146,7 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
   }
 
   if(hrf) {
-    float tr=protcopy.seqpars.get_RepetitionTime();
+    float tr=data->protcopy.seqpars.get_RepetitionTime();
     ODINLOG(odinlog,infoLog) << "Convolving with HRF and TR=" << tr << STD_endl;
     fvector designcopy(design);
     design=JDXfloat(0.0);
@@ -173,15 +177,17 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
   data->designdata=design;
 
 
+  Protocol maskprot(data->protcopy); // local copy for mask
+  
   data->has_mask=false;
   if(maskfile!="") {
     ODINLOG(odinlog,infoLog) << "Loading fMRI mask ..." << STD_endl;
-    if(data->mask.autoread(maskfile,ropts,&protcopy)<=0) {
+    if(data->mask.autoread(maskfile,ropts,&maskprot)<=0) {
       ODINLOG(odinlog,errorLog) << "Unable to load maskfile " << maskfile << STD_endl;
       return false;
     }
 
-    if(!filterchain.apply(protcopy, data->mask)) return false;
+    if(!filterchain.apply(maskprot, data->mask)) return false;
 
     TinyVector<int,4> fmrishape=data->fmri.shape(); fmrishape(0)=1;
     TinyVector<int,4> maskshape=data->mask.shape(); maskshape(0)=1;
@@ -212,6 +218,7 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
 
   data->pmap.resize(1,nz,ny,nx);
   data->zmap.resize(1,nz,ny,nx);
+  data->smap.resize(1,nz,ny,nx);
   data->brainvoxels=0;
   overlay_map.redim(nz,ny,nx);
   toberemoved.redim(nz,ny,nx);
@@ -226,16 +233,19 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
         onepixel=data->fmri(all,iz,iy,ix);
         float p=0.0;
         float z=0.0;
+        float sigchange=0.0;
         if(mean(onepixel)>sigthreshold) {
           correlationResult corr=correlation(data->designdata, onepixel);
           if(corr.r>0.0) { // take only positivie correlation
             p=corr.p;
             z=corr.z;
+            sigchange=fmri_eval(onepixel, data->designdata).rel_diff;
           }
           data->brainvoxels++;
         }
         data->pmap(0,iz,iy,ix)=p;
         data->zmap(0,iz,iy,ix)=z;
+        data->smap(0,iz,iy,ix)=sigchange;
       }
     }
   }
@@ -306,7 +316,15 @@ const farray& MiViewFmri::get_overlay_map() const {
 }
 
 
+bool MiViewFmri::write_overlay_map(const STD_string& filename) {
+  Data<float,3> tmpmap(get_overlay_map());
+  return (tmpmap.autowrite(dumpzmap,FileWriteOpts(),&(data->protcopy))>=0);
+}
+
+
 void MiViewFmri::update() {
+  Log<MiViewComp> odinlog("MiViewFmri","update");
+
   Range all=Range::all();
   int nz=data->pmap.extent(1);
   int ny=data->pmap.extent(2);
@@ -379,9 +397,19 @@ void MiViewFmri::update() {
     for(int i=0; i<nrep; i++) file << sigcourse[i] << "\n";
   }
 
+  ODINLOG(odinlog,normalDebug) << "dumpzmap=" << dumpzmap << STD_endl;
   if(dumpzmap!="") {
-    Data<float,3> tmpmap(get_overlay_map());
-    tmpmap.autowrite(dumpzmap);
+    write_overlay_map(dumpzmap);
+  }
+
+  ODINLOG(odinlog,normalDebug) << "dumpsmap=" << dumpsmap << STD_endl;
+  if(dumpsmap!="") {
+    Data<float,4> mask(get_overlay_map());
+    Data<float,4> smap_mask(data->smap.shape());
+
+    smap_mask=where(Array<float,4>(mask)>0.0, Array<float,4>(data->smap), float(0.0));
+
+    smap_mask.autowrite(dumpsmap,FileWriteOpts(),&(data->protcopy));
   }
 
 }
