@@ -42,6 +42,7 @@ class MiViewFmri : public JcampDxBlock {
   bool is_valid() const {return valid;}
 
   const farray& get_overlay_map() const;
+  bool write_overlay_map(const STD_string& filename);
 
   void update();
 
@@ -64,6 +65,7 @@ class MiViewFmri : public JcampDxBlock {
   JDXfloatArr sigcourse;
   JDXstring dumptcourse;
   JDXstring dumpzmap;
+  JDXstring dumpsmap;
 
   FmriData* data;
   mutable farray overlay_map;
