@@ -178,8 +178,10 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
     usage(); exit(0);
   }
 
+  ProgressDisplayConsole display;
+  ProgressMeter progmeter(display);
 
-  if(file->data.autoread(fname,ropts,&(file->prot))<=0) exit(-1);
+  if(file->data.autoread(fname,ropts,&(file->prot),&progmeter)<=0) exit(-1);
   ODINLOG(odinlog,normalDebug) << "mem(read): " << Profiler::get_memory_usage() << STD_endl;
 
   if(!filterchain.apply(file->prot, file->data)) exit(-1);
@@ -333,7 +335,7 @@ void MiViewView::writeFmriClusters() {
   if(clusters_fname_cache=="") return;
   STD_string format=check_and_get_format(clusters_fname_cache,FileIO::autoformats());
   if(format!="") {
-    Data<float,3>(fmri.get_overlay_map()).autowrite(clusters_fname_cache);
+    fmri.write_overlay_map(clusters_fname_cache);
 /*
     farray olmap(fmri.get_overlay_map());
     Data<float,4> maskdata(1,olmap.size(0),olmap.size(1),olmap.size(2)); maskdata=0.0;
