@@ -137,9 +137,9 @@ PlotView::PlotView(const char* method, const STD_string& nucleus, GuiMainWindow*
 
 
 
-  zoomflag[rect]=      new GuiToolButton(zoom_toolbar, rectIcon, "", this, SLOT(set_rect_zoom_tool()), true );
-  zoomflag[horizontal]=new GuiToolButton(zoom_toolbar, hortIcon, "", this, SLOT(set_hort_zoom_tool()), true );
-  zoomflag[vertical]=  new GuiToolButton(zoom_toolbar, vertIcon, "", this, SLOT(set_vert_zoom_tool()), true );
+  zoomflag[rect]=      new GuiToolButton(zoom_toolbar, rectIcon, "Rectangular Zoom", this, SLOT(set_rect_zoom_tool()), true );
+  zoomflag[horizontal]=new GuiToolButton(zoom_toolbar, hortIcon, "Horizontal Zoom",  this, SLOT(set_hort_zoom_tool()), true );
+  zoomflag[vertical]=  new GuiToolButton(zoom_toolbar, vertIcon, "Vertical Zoom",    this, SLOT(set_vert_zoom_tool()), true );
 
   markid_vertzoom=0;
   markid_hortzoom=0;
@@ -284,9 +284,13 @@ PlotView::PlotView(const char* method, const STD_string& nucleus, GuiMainWindow*
 
   chan_toolbar->add_separator();
   oscibutton=new GuiToolButton(chan_toolbar, 0, "Osci", this, SLOT(osci()));
+  oscibutton->set_tooltip("Triggered oscilloscope");
   printbutton=new GuiToolButton(chan_toolbar, 0, "Print", this, SLOT(print()));
+  printbutton->set_tooltip("Print sequence plot");
   savebutton=new GuiToolButton(chan_toolbar,  0, "Save", this, SLOT(save()));
+  savebutton->set_tooltip("Save sequence plot as multi-column ASCII file");
   closebutton=new GuiToolButton(chan_toolbar, 0, "Close", this, SLOT(close()));
+  closebutton->set_tooltip("Close sequence plot");
 
 
   plotAxes   =new GuiToolButton(settings_toolbar, 0, "Axes",    this, SLOT(settingsChanged()), true, true );
@@ -705,7 +709,7 @@ void PlotView::mousePressedInPlot (int iplot, const QMouseEvent& e) {
     plot_pressed=iplot;
     x_pressed=e.x();
     y_pressed=e.y();
-    
+
     if(zoomflag[horizontal]->is_on()) {
       markid_hortzoom=plotter[iplot]->insert_marker("",get_x(iplot,x_pressed),true,false);
       plotter[iplot]->replot();
@@ -743,8 +747,16 @@ void PlotView::mousePressedInPlot (int iplot, const QMouseEvent& e) {
     pm.insert_item("Refresh Plot", this, SLOT(replot()));
 
     if(closest) {
+
       iplot_cache=iplot;
-      pm.insert_item(("Save Curve \'"+STD_string(curves_map[iplot_cache][closest].label)+"\'").c_str(), this, SLOT(save_closest_curve_data()));
+      if(plotmode->get_current_item()==tcmode_curves) {
+        pm.insert_item(("Save Curve \'"+STD_string(curves_map[iplot_cache][closest].label)+"\'").c_str(), this, SLOT(save_closest_curve_data()));
+      } else {
+        STD_string chanlabel, chanunit;
+        get_plot_label(iplot, chanlabel, chanunit);
+        pm.insert_item(("Save Channel \'"+chanlabel+"\'").c_str(), this, SLOT(save_current_channel_data()));
+      }
+
     }
 
     ODINLOG(odinlog,normalDebug) << "e.pos=" << e.pos().x() << "/" << e.pos().y() << STD_endl;
@@ -831,26 +843,32 @@ void PlotView::update_x_axes() {
 }
 
 
+void PlotView::get_plot_label(int iplot, STD_string& label, STD_string& unit) const {
+
+  STD_string gradunit(timecourseUnit[plotmode->get_current_item()]);
+  STD_string gradprefix(timecoursePrefix[plotmode->get_current_item()]);
+
+  if(iplot==B1re_plotchan)   {label="B1re";   unit=ODIN_FIELD_UNIT;}
+  if(iplot==B1im_plotchan)   {label="B1im";   unit=ODIN_FIELD_UNIT;}
+  if(iplot==rec_plotchan)    {label="Rec";    unit="";}
+  if(iplot==signal_plotchan) {label="Signal"; unit="";}
+  if(iplot==freq_plotchan)   {label="Freq";   unit=ODIN_FREQ_UNIT;}
+  if(iplot==phase_plotchan)  {label="Phase";  unit=ODIN_ANGLE_UNIT;}
+  if(iplot==Gread_plotchan)  {label=gradprefix+"read"; unit=gradunit;}
+  if(iplot==Gphase_plotchan) {label=gradprefix+"phase"; unit=gradunit;}
+  if(iplot==Gslice_plotchan) {label=gradprefix+"slice"; unit=gradunit;}
+}
+
+
 void PlotView::set_plot_labels(bool extra_space) {
   if(plotAxes->is_on()) {
 
     STD_string cbtext;
     STD_string plotunit;
 
-    STD_string gradunit(timecourseUnit[plotmode->get_current_item()]);
-    STD_string gradprefix(timecoursePrefix[plotmode->get_current_item()]);
-
     for(int iplot=0; iplot<numof_plotchan; iplot++) {
 
-      if(iplot==B1re_plotchan)   {cbtext="B1re";   plotunit=ODIN_FIELD_UNIT;}
-      if(iplot==B1im_plotchan)   {cbtext="B1im";   plotunit=ODIN_FIELD_UNIT;}
-      if(iplot==rec_plotchan)    {cbtext="Rec";    plotunit="";}
-      if(iplot==signal_plotchan) {cbtext="Signal"; plotunit="";}
-      if(iplot==freq_plotchan)   {cbtext="Freq";   plotunit=ODIN_FREQ_UNIT;}
-      if(iplot==phase_plotchan)  {cbtext="Phase";  plotunit=ODIN_ANGLE_UNIT;}
-      if(iplot==Gread_plotchan)  {cbtext=gradprefix+"read"; plotunit=gradunit;}
-      if(iplot==Gphase_plotchan) {cbtext=gradprefix+"phase"; plotunit=gradunit;}
-      if(iplot==Gslice_plotchan) {cbtext=gradprefix+"slice"; plotunit=gradunit;}
+      get_plot_label(iplot, cbtext, plotunit);
 
       plotflag[iplot]->set_label(cbtext.c_str());
 
@@ -862,6 +880,7 @@ void PlotView::set_plot_labels(bool extra_space) {
   }
 }
 
+
 void PlotView::set_curve_pens(bool thick_lines) {
   int cpen_width=1;
   int bpen_width=1;
@@ -1029,6 +1048,28 @@ void PlotView::save_closest_curve_data() {
 }
 
 
+void PlotView::save_current_channel_data() {
+
+  timecourseMode type=timecourseMode(plotmode->get_current_item());
+  if(!create_timecourses(type)) return;
+
+  const SeqTimecourseData* timecourse=plotdata->get_timecourse(type);
+  if(!timecourse) return;
+
+
+  STD_string fname=get_save_filename("Save channel as ASCII", "", "", this);
+  if(fname=="") return;
+
+  STD_ofstream file(fname.c_str());
+
+  for(unsigned int i=0; i<timecourse->size; i++) {
+    file << timecourse->x[i] << "\t" << timecourse->y[iplot_cache][i] << "\n";
+  }
+
+  file.close();
+}
+
+
 void PlotView::osci() {
   Log<OdinComp> odinlog("PlotView","osci");
 
@@ -1172,9 +1213,7 @@ void PlotView::save() {
     file << "\n";
   }
 
-  
   file.close();
-    
 }
 
 
