@@ -147,7 +147,7 @@ class PlotView : public QWidget, public SeqSimFeedbackAbstract {
   void settingsChanged();
 
   void save_closest_curve_data();
-  
+  void save_current_channel_data();
 
  signals:
   void setMessage(const char* text);
@@ -171,8 +171,9 @@ class PlotView : public QWidget, public SeqSimFeedbackAbstract {
   void autoscale_all_y();
   void autoscale_y(int iplot);
   void rescale_y(int iplot, double val);
-  
 
+
+  void get_plot_label(int iplot, STD_string& label, STD_string& unit) const;
   void set_plot_labels(bool extra_space=false);
 
   void set_curve_pens(bool thick_lines=false);
