@@ -330,9 +330,38 @@ void ComplexData<N_rank>::shift_subpixel(const TinyVector<float,N_rank>& shiftve
 
 template <int N_rank>
 Data<float,N_rank> ComplexData<N_rank>::phasemap() const {
-  Data<float,N_rank> phasemap_result(phase(*this));
-  unwrapPhase1d(phasemap_result);
-  return phasemap_result;
+
+  Range all=Range::all();
+
+  const ComplexData<N_rank>& indata=*this;
+
+  TinyVector<int,N_rank> myshape(indata.shape());
+  Data<float,N_rank> result(myshape);
+
+  TinyVector<int,N_rank> ortho_shape(myshape);
+  ortho_shape(N_rank-1)=1;
+
+  int nlast=myshape(N_rank-1);
+  Data<float,1> phasevec(nlast);
+  Data<float,1> unwrapped(nlast);
+
+  TinyVector<int,N_rank> indexvec;
+
+  for(int iortho=0; iortho<product(ortho_shape); iortho++) {
+    indexvec=index2extent<N_rank>(ortho_shape,iortho);
+    int ilast;
+    for(ilast=0; ilast<nlast; ilast++) {
+      indexvec(N_rank-1)=ilast;
+      phasevec(ilast)=phase(indata(indexvec));
+    }
+    unwrapped=unwrap_phase(phasevec, nlast/2);
+    for(ilast=0; ilast<nlast; ilast++) {
+      indexvec(N_rank-1)=ilast;
+      result(indexvec)=unwrapped(ilast);
+    }
+  }
+
+  return result;
 }
 
 
