@@ -88,7 +88,6 @@ static unsigned int get_elements(const T&) {
 template<typename Src, typename Dst>
 static void convert_array(const Src* src, Dst* dst, unsigned int srcsize, unsigned int dstsize, autoscaleOption scaleopt=autoscale) {
   Log<OdinData> odinlog("Converter","convert_array");
-  init();
   unsigned int srcstep=get_elements(*dst);
   unsigned int dststep=get_elements(*src);
   bool doScale = (scaleopt!=noscale && std::numeric_limits<Dst>::is_integer);
@@ -170,8 +169,6 @@ static void convert_array(const Src* src, Dst* dst, unsigned int srcsize, unsign
   }
 }
 
-static void init();
-
 private:
 
 //////////////////////////////////////////////////////////
@@ -188,125 +185,6 @@ template<typename Src, typename Dst> static void convert_array_impl(const Src* s
 		convert(src++, dst++,scale,offset);
 }
 
-#ifdef USE_OIL
-#define DECL_CONVERT(SRC_TYPE,DST_TYPE,SRC_KEY,DST_KEY) static void convert_array_impl(const SRC_TYPE  *src,DST_TYPE *dst, unsigned int count);
-#define DECL_SCALED_CONVERT(SRC_TYPE,DST_TYPE,SRC_KEY,DST_KEY) static void convert_array_impl(const SRC_TYPE  *src,DST_TYPE *dst, unsigned int count,const double scale,const double offset);
-
-//>>s32
-DECL_CONVERT(float,int32_t,f32,s32)
-DECL_CONVERT(double,int32_t,f64,s32)
-DECL_CONVERT(uint32_t,int32_t,u32,s32)
-DECL_CONVERT(int16_t,int32_t,s16,s32)
-DECL_CONVERT(uint16_t,int32_t,u16,s32)
-DECL_CONVERT(int8_t,int32_t,s8,s32)
-DECL_CONVERT(uint8_t,int32_t,u8,s32)
-
-//>>u32
-//DECL_CONVERT(float,uint32_t,f32,u32) conversion to u32 is broken (https://bugs.freedesktop.org/show_bug.cgi?id=16524)
-//DECL_CONVERT(double,uint32_t,f64,u32)
-DECL_CONVERT(int32_t,uint32_t,s32,u32)
-//DECL_CONVERT(int16_t,uint32_t,s16,u32) ** Not available in liboil - but should be imho
-DECL_CONVERT(uint16_t,uint32_t,u16,u32)
-//DECL_CONVERT(int8_t,uint32_t,s8,u32) ** Not available in liboil - but should be imho
-DECL_CONVERT(uint8_t,uint32_t,u8,u32)
-
-//>>s16
-DECL_CONVERT(float,int16_t,f32,s16)
-DECL_CONVERT(double,int16_t,f64,s16)
-DECL_CONVERT(int32_t,int16_t,s32,s16)
-DECL_CONVERT(uint32_t,int16_t,u32,s16)
-DECL_CONVERT(uint16_t,int16_t,u16,s16)
-DECL_CONVERT(int8_t,int16_t,s8,s16)
-DECL_CONVERT(uint8_t,int16_t,u8,s16)
-
-//>>u16
-DECL_CONVERT(float,uint16_t,f32,u16)
-DECL_CONVERT(double,uint16_t,f64,u16)
-DECL_CONVERT(int32_t,uint16_t,s32,u16)
-DECL_CONVERT(uint32_t,uint16_t,u32,u16)
-DECL_CONVERT(int16_t,uint16_t,s16,u16)
-//DECL_CONVERT(int8_t,uint16_t,s8,u16) ** Not available in liboil - but should be imho
-DECL_CONVERT(uint8_t,uint16_t,u8,u16)
-
-//>>s8
-DECL_CONVERT(float,int8_t,f32,s8)
-DECL_CONVERT(double,int8_t,f64,s8)
-DECL_CONVERT(int32_t,int8_t,s32,s8)
-DECL_CONVERT(uint32_t,int8_t,u32,s8)
-DECL_CONVERT(int16_t,int8_t,s16,s8)
-DECL_CONVERT(uint16_t,int8_t,u16,s8)
-DECL_CONVERT(uint8_t,int8_t,u8,s8)
-
-//>>u8
-DECL_CONVERT(float,uint8_t,f32,u8)
-DECL_CONVERT(double,uint8_t,f64,u8)
-DECL_CONVERT(int32_t,uint8_t,s32,u8)
-DECL_CONVERT(uint32_t,uint8_t,u32,u8)
-DECL_CONVERT(int16_t,uint8_t,s16,u8)
-DECL_CONVERT(uint16_t,uint8_t,u16,u8)
-DECL_CONVERT(int8_t,uint8_t,s8,u8)
-
-//>>f32
-DECL_CONVERT(double,float,f64,f32)
-DECL_CONVERT(int32_t,float,s32,f32)
-DECL_CONVERT(uint32_t,float,u32,f32)
-DECL_CONVERT(int16_t,float,s16,f32)
-DECL_CONVERT(uint16_t,float,u16,f32)
-DECL_CONVERT(int8_t,float,s8,f32)
-DECL_CONVERT(uint8_t,float,u8,f32)
-
-//>>f64
-DECL_CONVERT(float,double,f32,f64)
-DECL_CONVERT(int32_t,double,s32,f64)
-DECL_CONVERT(uint32_t,double,u32,f64)
-DECL_CONVERT(int16_t,double,s16,f64)
-DECL_CONVERT(uint16_t,double,u16,f64)
-DECL_CONVERT(int8_t,double,s8,f64)
-DECL_CONVERT(uint8_t,double,u8,f64)
-
-//scale>>s32
-DECL_SCALED_CONVERT(float,int32_t,f32,s32)
-DECL_SCALED_CONVERT(double,int32_t,f64,s32)
-
-//scale>>u32
-//DECL_SCALED_CONVERT(float,uint32_t,f32,u32) conversion to u32 is broken (https://bugs.freedesktop.org/show_bug.cgi?id=16524)
-//DECL_SCALED_CONVERT(double,uint32_t,f64,u32)
-
-//scale>>s16
-DECL_SCALED_CONVERT(float,int16_t,f32,s16)
-DECL_SCALED_CONVERT(double,int16_t,f64,s16)
-
-//scale>>u16
-DECL_SCALED_CONVERT(float,uint16_t,f32,u16)
-DECL_SCALED_CONVERT(double,uint16_t,f64,u16)
-
-//scale>>s8
-DECL_SCALED_CONVERT(float,int8_t,f32,s8)
-DECL_SCALED_CONVERT(double,int8_t,f64,s8)
-
-//scale>>u8
-DECL_SCALED_CONVERT(float,uint8_t,f32,u8)
-DECL_SCALED_CONVERT(double,uint8_t,f64,u8)
-
-//scale>>f32
-DECL_SCALED_CONVERT(int32_t,float,s32,f32)
-DECL_SCALED_CONVERT(uint32_t,float,u32,f32)
-DECL_SCALED_CONVERT(int16_t,float,s16,f32)
-DECL_SCALED_CONVERT(uint16_t,float,u16,f32)
-DECL_SCALED_CONVERT(int8_t,float,s8,f32)
-DECL_SCALED_CONVERT(uint8_t,float,u8,f32)
-
-//scale>>f64
-DECL_SCALED_CONVERT(int32_t,double,s32,f64)
-DECL_SCALED_CONVERT(uint32_t,double,u32,f64)
-DECL_SCALED_CONVERT(int16_t,double,s16,f64)
-DECL_SCALED_CONVERT(uint16_t,double,u16,f64)
-DECL_SCALED_CONVERT(int8_t,double,s8,f64)
-DECL_SCALED_CONVERT(uint8_t,double,u8,f64)
-
-#undef DECL_CONVERT
-#undef DECL_SCALED_CONVERT
-#endif //USE_OIL
 
 
 // Implementing our own round functions since lround/lroundf do not work for unsigned numbers, and they are flawed in MinGW
