@@ -150,7 +150,12 @@ correlationResult kendall(const Array<T,N_rank>& x, const Array<T,N_rank>& y) {
   */
 struct fmriResult {
 
-  fmriResult() : Srest(0.0), Sstim(0.0), rel_diff(0.0), rel_err(0.0) {}
+  fmriResult() : Sbaseline(0.0), Srest(0.0), Sstim(0.0), rel_diff(0.0), rel_err(0.0) {}
+
+/**
+  * Signal during baseline (leading timesteps with zeroes in design file)
+  */
+  float Sbaseline;
 
 /**
   * Signal during rest
