@@ -116,7 +116,7 @@ struct FileMapHandle {
 /**
   * This template class holds multidimensional data. In addition to functionality
   * provided by the Blitz Array class, it offers methods to read/write raw data
-  * and and other file formats (vista, vtk, ...) to/from a file.
+  * and and other file formats (nifti, vtk, ...) to/from a file.
   * In addition, uing a special constructor, the array can be associated with a block
   * of data on disk using the UNIX mmap functionality. In this case, any changes made
   * to the array will be automatically tranfered to the file. Please note that any
@@ -169,7 +169,7 @@ public:
   Data(const Array<T,N_rank>& a) : Array<T,N_rank>(a), fmap(0) {}
 
 /**
-  * Constructor from an equivalent tjarray (\ref arrays)
+  * Constructor from an equivalent tjarray (\ref arrays). If rank of 'a' is smaller, extent will pe padded with 1 at front.
   */
   Data(const tjarray<tjvector<T>,T>& a) : fmap(0) { (*this)=a;}
 
@@ -212,7 +212,7 @@ public:
   }
 
 /**
-  * Assignment from an equivalent tjarray (\ref arrays)
+  * Assignment from an equivalent tjarray (\ref arrays). If rank of 'a' is smaller, extent will pe padded with 1 at front.
   */
   Data<T,N_rank>& operator = (const tjarray<tjvector<T>,T>& a);
 
@@ -302,9 +302,10 @@ public:
 /**
   * Reads data set from file 'filename' assuming the format automatically detected by the given file extension.
   * Extra options can be given by 'opts' and protocol settings will be stored in 'prot'.
+  * The progress meter 'progmeter' can be optionally specified to monitor the progress of the operation.
   * Returns number of slices sucessfully read, or -1 if it fails.
   */
-  int autoread(const STD_string& filename, const FileReadOpts& opts=FileReadOpts(), Protocol* prot=0);
+  int autoread(const STD_string& filename, const FileReadOpts& opts=FileReadOpts(), Protocol* prot=0, ProgressMeter* progmeter=0);
 
 /**
   * Returns true if the array is associated with a file on disk
@@ -507,13 +508,17 @@ void Data<T,N_rank>::reference(const Data<T,N_rank>& d) {
 template <typename T, int N_rank>
 Data<T,N_rank>& Data<T,N_rank>::operator = (const tjarray<tjvector<T>,T>& a) {
   Log<OdinData> odinlog("Data","=");
-  if( a.dim() == N_rank ) {
+  if( a.dim() <= N_rank ) {
     ndim nn=a.get_extent();
+    int npad=N_rank-nn.dim();
+    ODINLOG(odinlog,normalDebug) << "npad=" << npad << STD_endl;
+    for(int ipad=0; ipad<npad; ipad++) nn.add_dim(1, true); // pad at front
+    ODINLOG(odinlog,normalDebug) << "nn(pad)" << nn << STD_endl;
     TinyVector<int,N_rank> tv;
-    for(unsigned int i=0;i<a.dim();i++) tv(i)=nn[i];
+    for(unsigned int i=0; i<N_rank; i++) tv(i)=nn[i];
     resize(tv);
     for(unsigned int i=0;i<a.total();i++) (*this)(create_index(i))=a[i];
-  } else ODINLOG(odinlog,errorLog) << "dimension mismatch: this=" << N_rank<< ", tjarray=" << a.dim() << STD_endl;
+  } else ODINLOG(odinlog,errorLog) << "dimension mismatch: this=" << N_rank<< " < tjarray=" << a.dim() << STD_endl;
   return *this;
 }
 
@@ -691,7 +696,7 @@ int Data<T,N_rank>::read_asc_file(const STD_string& filename) {
 
 // Interface to FileIO functionality
 int fileio_autowrite(const Data<float,4>& data, const STD_string& filename, const FileWriteOpts& opts, const Protocol* prot);
-int fileio_autoread(Data<float,4>& data, const STD_string& filename, const FileReadOpts& opts, Protocol* prot);
+int fileio_autoread(Data<float,4>& data, const STD_string& filename, const FileReadOpts& opts, Protocol* prot, ProgressMeter* progmeter);
 
 
 template<typename T,int N_rank>
@@ -701,9 +706,9 @@ int Data<T,N_rank>::autowrite(const STD_string& filename, const FileWriteOpts& o
 }
 
 template<typename T,int N_rank>
-int Data<T,N_rank>::autoread(const STD_string& filename, const FileReadOpts& opts, Protocol* prot) {
+int Data<T,N_rank>::autoread(const STD_string& filename, const FileReadOpts& opts, Protocol* prot, ProgressMeter* progmeter) {
   Data<float,4> filedata;
-  int result=fileio_autoread(filedata, filename, opts, prot);
+  int result=fileio_autoread(filedata, filename, opts, prot, progmeter);
   if(result>0) filedata.convert_to(*this);
   return result;
 }
