@@ -67,8 +67,12 @@ STD_string FileFormat::analyze_suffix(const STD_string& filename) {
 }
 
 FileFormat* FileFormat::get_format(const STD_string& filename, const STD_string& override_suffix) {
-  JDXfileName fname(filename);
-  STD_string suffix= override_suffix!=AUTODETECTSTR ? override_suffix : analyze_suffix(filename);
+  STD_string suffix;
+  if(override_suffix==AUTODETECTSTR) {
+    suffix=analyze_suffix(filename);
+  } else {
+    suffix=override_suffix;
+  }
   if(formats.find(suffix)!=formats.end()) return formats[suffix];
   return 0;
 }
@@ -204,15 +208,20 @@ svector FileFormat::create_unique_filenames(const STD_string& filename, const Fi
 
 
 float FileFormat::voxel_extent(const Geometry& geometry, direction direction, int size) {
+  Log<FileIO> odinlog("FileFormat","voxel_extent");
   float result;
   if(direction==sliceDirection) {
-    if(geometry.get_Mode()==voxel_3d) result=secureDivision(geometry.get_FOV(direction),  size);
-    else {
+    if(geometry.get_Mode()==voxel_3d) {
+      result=secureDivision(geometry.get_FOV(direction),  size);
+    } else {
       if(geometry.get_nSlices()>1) result=geometry.get_sliceDistance();
       else                         result=geometry.get_sliceThickness();
     }
-  } else
+  } else {
     result=secureDivision(geometry.get_FOV(direction),  size);
+  }
+
+  ODINLOG(odinlog,normalDebug) << "result(" << directionLabel[direction] << ")=" << result << STD_endl;
 
   return result;
 }
@@ -233,7 +242,6 @@ void register_nifti_format();
 void register_png_format();
 void register_raw_format();
 void register_Iris3D_format();
-void register_vista_format();
 void register_vtk_format();
 
 //////////////////////////////////////////////////////////////
@@ -253,7 +261,6 @@ struct FileFormatCreator : public StaticHandler<FileFormatCreator> {
     register_Iris3D_format();
     register_raw_format();
     register_hfss_format();
-    register_vista_format();
     register_vtk_format();
   }
   static void destroy_static() {}
@@ -265,7 +272,7 @@ EMPTY_TEMPL_LIST bool StaticHandler<FileFormatCreator>::staticdone=false;
 //////////////////////////////////////////////////////////////////////////
 
 
-int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const FileReadOpts& opts, const Protocol& protocol_template,ProgressMeter *progmeter) {
+int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const FileReadOpts& opts, const Protocol& protocol_template,ProgressMeter* progmeter) {
   Log<FileIO> odinlog("FileIO","autoread");
 
   if(!checkdir(filename.c_str()) && filesize(filename.c_str())<=0) {
@@ -341,7 +348,10 @@ int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const F
       pdmap[prot].reference(data);
     }
 
-    ODINLOG(odinlog,loglevel()) << "Read dataset " << cnt << " from file " << filename << "  with dimensions " << shape << STD_endl;
+    STD_string cntstr;
+    if(pdmapin.size()>1) cntstr="#"+itos(cnt)+" ";
+
+    ODINLOG(odinlog,loglevel()) << "Read dataset " << cntstr << "from file " << filename << "  with dimensions " << shape << STD_endl;
 
     cnt++;
   }
@@ -353,7 +363,7 @@ int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const F
   if(opts.dset!="") {
     dset2extract=atoi(opts.dset.c_str());
     if(dset2extract>=int(pdmap.size()) || dset2extract<0) {
-      ODINLOG(odinlog,errorLog) << "Dataset to exctract (" << dset2extract << ") out of range (" << pdmap.size() << ")" << STD_endl;
+      ODINLOG(odinlog,errorLog) << "Dataset to extract (" << dset2extract << ") out of range (" << pdmap.size() << ")" << STD_endl;
       return -1;
     }
   }
@@ -420,7 +430,7 @@ struct ImageKey : public UniqueIndex<ImageKey> {
 
 typedef STD_map<ImageKey,Data<float,2> > KeyImageMap;
 
-int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const FileReadOpts& opts, const Protocol& protocol_template,ProgressMeter *progmeter) {
+int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const FileReadOpts& opts, const Protocol& protocol_template,ProgressMeter* progmeter) {
   Log<FileIO> odinlog("FileIO","read_dir");
 
   ODINLOG(odinlog,normalDebug) << "mem(start): " << Profiler::get_memory_usage() << STD_endl;
@@ -441,8 +451,8 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
   // Use local options to skip some of the global autoread options
   FileReadOpts opts_copy=opts;
   opts_copy.dset="";
-  if(progmeter)progmeter->new_task( nfiles,"reading files from directory");
 
+  if(progmeter) progmeter->new_task( nfiles,"FileIO::read_dir");
   
   for(unsigned int i=0; i<nfiles; i++) {
 
@@ -499,7 +509,9 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
             dataref.resize(onefiledata.extent(phaseDim),onefiledata.extent(readDim));
             dataref=onefiledata(irep,islice,all,all);
 
-            if(!progmeter) ODINLOG(odinlog,loglevel()) << "Read slice from file " << dirfiles[i] << " "  <<  onefiledata.shape() << " with acquisition_start/slice_location=" << acqstart << "/" << sliceloc << STD_endl;
+            if(!progmeter) {
+              ODINLOG(odinlog,loglevel()) << "Read slice from file " << dirfiles[i] << " "  <<  onefiledata.shape() << " with acquisition_start/slice_location=" << acqstart << "/" << sliceloc << STD_endl;
+            }
           }
         }
       } // end iterating over protocol-data pairs
@@ -813,7 +825,7 @@ void create_fileio_testarr(Data<float,4>& testarr, const TinyVector<int,4>& shap
   }
 }
 
-template <int XSize, int YSize, typename CompareType, bool ReadDir, bool HasOrientation, bool HasSliceThick>
+template <int XSize, int YSize, typename CompareType, bool OnlyBitmap, bool ReadDir, bool HasOrientation, bool HasSliceThick>
 class FileIOFormatTest : public UnitTest {
 
  public:
@@ -853,9 +865,12 @@ class FileIOFormatTest : public UnitTest {
     FileIO::set_trace_status(false); // disable logging to console
 
     STD_list<TinyVector<int,4> > shapelst;
-    shapelst.push_back(TinyVector<int,4>(3,4,YSize,XSize));
-    shapelst.push_back(TinyVector<int,4>(1,4,YSize,XSize));
-    shapelst.push_back(TinyVector<int,4>(3,1,YSize,XSize));
+    shapelst.push_back(TinyVector<int,4>(1,1,YSize,XSize));
+    if(!OnlyBitmap) {
+      shapelst.push_back(TinyVector<int,4>(3,4,YSize,XSize));
+      shapelst.push_back(TinyVector<int,4>(1,4,YSize,XSize));
+      shapelst.push_back(TinyVector<int,4>(3,1,YSize,XSize));
+    }
 
     for(STD_list<TinyVector<int,4> >::const_iterator it=shapelst.begin(); it!=shapelst.end(); ++it) {
 
@@ -881,32 +896,34 @@ class FileIOFormatTest : public UnitTest {
       if(!compare_arrays("autowrite/autoread("+readfname+")", testarr, readdata)) return false;
 
       // Testing whether geometry info is preserved
-      Protocol prot;
-      Geometry& geo=prot.geometry;
-      if(HasOrientation) {
-        geo.set_orientation(-66.7, 78.2, -124.7);
-        geo.set_offset(readDirection,22.7);
-        geo.set_offset(phaseDirection,-5.9);
-        geo.set_offset(sliceDirection,99.9);
-      }
-      geo.set_FOV(readDirection,192.6);
-      geo.set_FOV(phaseDirection,200.2);
-      geo.set_nSlices(testarr.extent(1));
-      geo.set_sliceDistance(6.1);
-      if(HasSliceThick) {
-        geo.set_sliceThickness(3.2);
-      } else {
-        geo.set_sliceThickness(6.1); // the same as slice distance
-      }
-      if(testarr.autowrite(writefname, FileWriteOpts(), &prot)<0) return false;
-      Protocol readprot;
-      if(readdata.autoread(readfname, readopts, &readprot)<0) return false;
-      if(!compare_arrays("autowrite/autoread+geo("+readfname+")", testarr, readdata)) return false;
-      Protocol protcopy(prot); // Create copy of protocol to use limited accuracy comparison of Protocol
-      protcopy.geometry=readprot.geometry; // only geometry may differ
-      if(!(prot==protcopy)) { // use limited accuracy comparison of Protocol
-        ODINLOG(odinlog,errorLog) << "autowrite/autoread(geo)" << (*it) << " failed: prot.geometry=" << prot.geometry << "protcopy.geometry=" << protcopy.geometry << STD_endl;
-        return false;
+      if(!OnlyBitmap) {
+        Protocol prot;
+        Geometry& geo=prot.geometry;
+        if(HasOrientation) {
+          geo.set_orientation(-66.7, 78.2, -124.7);
+          geo.set_offset(readDirection,22.7);
+          geo.set_offset(phaseDirection,-5.9);
+          geo.set_offset(sliceDirection,99.9);
+        }
+        geo.set_FOV(readDirection,192.6);
+        geo.set_FOV(phaseDirection,200.2);
+        geo.set_nSlices(testarr.extent(1));
+        geo.set_sliceDistance(6.1);
+        if(HasSliceThick) {
+          geo.set_sliceThickness(3.2);
+        } else {
+          geo.set_sliceThickness(6.1); // the same as slice distance
+        }
+        if(testarr.autowrite(writefname, FileWriteOpts(), &prot)<0) return false;
+        Protocol readprot;
+        if(readdata.autoread(readfname, readopts, &readprot)<0) return false;
+        if(!compare_arrays("autowrite/autoread+geo("+readfname+")", testarr, readdata)) return false;
+        Protocol protcopy(prot); // Create copy of protocol to use limited accuracy comparison of Protocol
+        protcopy.geometry=readprot.geometry; // only geometry may differ
+        if(!(prot==protcopy)) { // use limited accuracy comparison of Protocol
+          ODINLOG(odinlog,errorLog) << "autowrite/autoread(geo)" << (*it) << " failed: prot.geometry=" << prot.geometry << "protcopy.geometry=" << protcopy.geometry << STD_endl;
+          return false;
+        }
       }
     }
 
@@ -923,25 +940,27 @@ void alloc_FileIOTest() { // create test instances
 
   new FileIOTest;
 
-  new FileIOFormatTest<7, 13, double, false,true,true>("jdx");
+  new FileIOFormatTest<7, 13, double, false,false,true,true>("jdx");
+
+#ifdef PNGSUPPORT
+  new FileIOFormatTest<7, 13, u8bit, true,false,false,false>("png");
+#endif
+
 #ifdef HAVE_LIBZ
 #ifndef STREAM_REPLACEMENT
-  new FileIOFormatTest<7, 13, double, false,true,true>("jdx.gz");
+  new FileIOFormatTest<7, 13, double, false,false,true,true>("jdx.gz");
 #endif
 #endif
 
 #ifdef DICOMSUPPORT
-  new FileIOFormatTest<16, 16, u16bit, true,true,true>("dcm"); // needs square matrix size
-#endif
-#ifdef VISTASUPPORT
-  new FileIOFormatTest<7, 13, double, false,true,true>("v");
+  new FileIOFormatTest<16, 16, u16bit, false,true,true,true>("dcm"); // needs square matrix size
 #endif
 #ifdef NIFTISUPPORT
-  new FileIOFormatTest<7, 13, double, false,true,false>("nii");
-  new FileIOFormatTest<7, 13, double, false,false,false>("hdr");
+  new FileIOFormatTest<7, 13, double, false,false,true,false>("nii");
+  new FileIOFormatTest<7, 13, double, false,false,false,false>("hdr");
 #ifdef HAVE_LIBZ
 #ifndef STREAM_REPLACEMENT
-  new FileIOFormatTest<7, 13, double, false,true,false>("nii.gz");
+  new FileIOFormatTest<7, 13, double, false,false,true,false>("nii.gz");
 #endif
 #endif
 #endif
