@@ -9,12 +9,17 @@ struct AsciiFormat : public FileFormat {
     result[0]="asc";
     return result;
   }
-  svector dialects() const {return svector();}
+  svector dialects() const {
+    svector result; result.resize(1);
+    result[0]="tcourse";
+    return result;
+  }
   int read(Data<float,4>& data, const STD_string& filename, const FileReadOpts& opts, Protocol& prot) {
     STD_string ascfile;
     ::load(ascfile,filename);
     unsigned int nelements=tokens(ascfile).size();
-    data.resize(1,nelements,1,1);
+    if(tolowerstr(opts.dialect)=="tcourse") data.resize(nelements,1,1,1);
+    else                                    data.resize(1,nelements,1,1);
     if(data.read_asc_file(filename)<0) return -1;
     return nelements;
   }
