@@ -117,11 +117,6 @@ template<typename T> void copy(const DiPixel *pix, Data<float,4> &dst,const Tiny
 
   T* src=(T*)pix->getData();
 
-  T max =0;
-//  assert(pix->getCount()>=product(shape));//for mosaic the pixel-count could be more that the target-"volume"
-  for(unsigned int i=0; i<pix->getCount(); i++) {
-    if(src[i]>max) max=src[i];
-  }
   const Range all=Range::all();
 
   if(shape(1)>1) { // Sort Siemens Mosaic data
@@ -157,45 +152,44 @@ template<typename BASE,typename DST> DST endian(const BASE *b){
 }
 
 
-sarray fetch_from_CSA(DcmDataset* dset,STD_string label){
-  Log<FileIO> odinlog("DicomFormat","fetch_from_CSA");
+svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
+  Log<FileIO> odinlog("DicomFormat","fetch_from_MR_CSA_Header");
 
-  DcmElement *elem;
-  sarray ret;
-  if(dset->findAndGetElement(DcmTagKey(0x0029,0x1010),elem).good()){
-    Uint8 *array;
-    elem->getUint8Array(array);
-    for(STD_string::size_type pos=0;pos<=elem->getLength();){
-      STD_string dummy((char*)array+pos);
-      STD_string::size_type found=dummy.find(label);
-      if(found==STD_string::npos)pos+=dummy.length()+1;
-      else{
-        pos+=found+0x40; //len of the name is 0x20 plus 0x20 "I dont know what the hell this is supposed to be"
-        /*Sint32 &vm=*((Sint32*)array+pos);*/pos+=sizeof(Sint32);
-        /*char *vr=(char*)array+pos;*/pos+=0x4;
-        /*Sint32 syngodt=endian<Uint8,Uint32>(array+pos);*/pos+=sizeof(Sint32);
-        Sint32 nitems=endian<Uint8,Uint32>(array+pos);pos+=sizeof(Sint32);
-        if(nitems){
-          pos+=sizeof(Sint32); //77
-          Sint32 len=0;
-          for(unsigned short n=0;n<nitems;n++){
-            len=endian<Uint8,Uint32>(array+pos);pos+=sizeof(Sint32);//the length of this element
-            pos+=3*sizeof(Sint32); //whatever
-            if(!len)continue;
-            const unsigned s=ret.length();ret.resize(s+1);
-            ret(s)=STD_string((char*)array+pos);//store the text if the is some
-            pos+=((len+sizeof(Sint32)-1)/sizeof(Sint32))*sizeof(Sint32);//increment pos by len aligned to sizeof(Sint32)
-          }
-          ODINLOG(odinlog,normalDebug) << "Found \""+label+"\" in CSA header: \"" << ret.printbody() << "\"" << STD_endl;
-
-        } else {
-          ODINLOG(odinlog,normalDebug) << "Found empty \""+label+"\" in CSA header" << STD_endl;
+  svector ret;
+  Uint8 *array;
+  csaHeader->getUint8Array(array);
+  for(STD_string::size_type pos=0;pos<=csaHeader->getLength();){
+    STD_string dummy((char*)array+pos);
+    STD_string::size_type found=dummy.find(label);
+    if(found==STD_string::npos) {
+      pos+=dummy.length()+1;
+    } else {
+      pos+=found+0x40; //len of the name is 0x20 plus 0x20 "I dont know what the hell this is supposed to be"
+      /*Sint32 &vm=*((Sint32*)array+pos);*/pos+=sizeof(Sint32);
+      /*char *vr=(char*)array+pos;*/pos+=0x4;
+      /*Sint32 syngodt=endian<Uint8,Uint32>(array+pos);*/pos+=sizeof(Sint32);
+      Sint32 nitems=endian<Uint8,Uint32>(array+pos);pos+=sizeof(Sint32);
+      if(nitems) {
+        pos+=sizeof(Sint32); //77
+        Sint32 len=0;
+        for(unsigned short n=0;n<nitems;n++){
+          len=endian<Uint8,Uint32>(array+pos);pos+=sizeof(Sint32);//the length of this element
+          pos+=3*sizeof(Sint32); //whatever
+          if(!len)continue;
+          const unsigned s=ret.size();ret.resize(s+1);
+          ret[s]=STD_string((char*)array+pos);//store the text if the is some
+          pos+=((len+sizeof(Sint32)-1)/sizeof(Sint32))*sizeof(Sint32);//increment pos by len aligned to sizeof(Sint32)
         }
-        return ret;
+        ODINLOG(odinlog,normalDebug) << "Found \""+label+"\" in CSA header: \"" << ret.printbody() << "\"" << STD_endl;
+
+      } else {
+        ODINLOG(odinlog,normalDebug) << "Found empty \""+label+"\" in CSA header" << STD_endl;
       }
+      return ret;
     }
-    ODINLOG(odinlog,normalDebug) << "Could not find\""+label+"\" in CSA header: " << STD_endl;
   }
+  ODINLOG(odinlog,normalDebug) << "Could not find\""+label+"\" in CSA header: " << STD_endl;
+
   return ret;
 }
 
@@ -232,6 +226,9 @@ struct DicomFormat : public FileFormat {
 
     if(JDXfileName(filename).get_basename()=="DICOMDIR") return 0; // ignore DICOMDIR
 
+#ifdef OFLOG_H
+    OFLog::configure(OFLogger::WARN_LOG_LEVEL); // reset logging (in dcmtk 3.6.0 info logging is somehow enabled sometimes)
+#endif
 
     DcmFileFormat fileformat;
     DcmDataset* dset=0;
@@ -246,6 +243,25 @@ struct DicomFormat : public FileFormat {
     }
 
 
+    DcmElement* csaHeader=0;
+    if(dset->findAndGetElement(DcmTagKey(0x0029,0x1010),csaHeader).good()) {
+      ODINLOG(odinlog,normalDebug) << "found Siemens-specific CSA Header" << STD_endl;
+/*
+      Uint8* array=0;
+      csaHeader->getUint8Array(array);
+      if(array) {
+        DcmElement* csaData=0;
+        if(dset->findAndGetElement(DcmTagKey(0x7fe1,0x1010),csaData).good()) {
+          ODINLOG(odinlog,infoLog) << "csaData->getLength()=" << csaData->getLength() << STD_endl;
+
+          STD_string csaHeaderStr((const char*)array, csaHeader->getLength());
+          STD_cout << csaHeaderStr << STD_endl;
+        }
+      }
+*/
+    }
+
+
     DicomImage img(dset, EXS_Unknown, CIF_IgnoreModalityTransformation); // apply modality transform manually to get higher floating point accuracy
 
     EI_Status status=img.getStatus();
@@ -280,16 +296,21 @@ struct DicomFormat : public FileFormat {
     // Hack for Siemens Mosaic
     int mosaic_mult=1;
     Sint16 mosaic_slices=1;
-    DcmElement *elem;
 
     //try to find 0x0019,100a (images per mosaic)
     if(image_type.find("MOSAIC")!=STD_string::npos) {
       if(dset->findAndGetSint16(DcmTagKey(0x0019,0x100a),mosaic_slices).good()){
         ODINLOG(odinlog,normalDebug) << "Found \"NumberOfImagesInMosaic\" in 0x0019,0x100a: " << mosaic_slices << STD_endl;
-      } else if(dset->findAndGetElement(DcmTagKey(0x0029,0x1010),elem).good())
-        //othwise find NumberOfImagesInMosaic in Siemens shadow Header 0x0029,0x1010
-        mosaic_slices=atoi(fetch_from_CSA(dset,"NumberOfImagesInMosaic")(0).c_str());
-
+      } else {
+        if(csaHeader) {
+          //othwise find NumberOfImagesInMosaic in Siemens shadow Header 0x0029,0x1010
+          svector csa_mosaic=fetch_from_MR_CSA_Header(csaHeader,"NumberOfImagesInMosaic");
+          if(csa_mosaic.size()) {
+            mosaic_slices=atoi(csa_mosaic[0].c_str());
+            ODINLOG(odinlog,normalDebug) << "Found \"NumberOfImagesInMosaic\" in CSADataInfo: " << mosaic_slices << STD_endl;
+          }
+        }
+      }
       if(mosaic_slices>1) {
         mosaic_mult=(int)ceil(sqrt((double)mosaic_slices));
         ODINLOG(odinlog,normalDebug) << "mosaic_mult=" << mosaic_mult << STD_endl;
@@ -651,6 +672,10 @@ struct DicomFormat : public FileFormat {
 
     JDXfileName fname(filename);
 
+#ifdef OFLOG_H
+    OFLog::configure(OFLogger::WARN_LOG_LEVEL); // reset logging (in dcmtk 3.6.0 info logging is somehow enabled sometimes)
+#endif
+
     // Create directory to store DICOMS
     DicomDirInterface dicomdir;
     JDXfileName dstdir; dstdir.set_dir(true);
