@@ -10,7 +10,8 @@ void FilterGenMask::init(){
 
 bool FilterGenMask::process(Data<float,4>& data, Protocol& prot) const {
 
-  TinyVector<int,4> datashape=data.shape();
+/*
+TinyVector<int,4> datashape=data.shape();
   TinyVector<int,4> maskshape=data.shape();
   maskshape(timeDim)=1;
 
@@ -28,8 +29,9 @@ bool FilterGenMask::process(Data<float,4>& data, Protocol& prot) const {
   }
 
   data.reference(mask);
+*/
 
-//  data=where(Array<float,4>(data)>=min && Array<float,4>(data)<=max, float(1.0), float(0.0));
+  data=where(Array<float,4>(data)>=min && Array<float,4>(data)<=max, float(1.0), float(0.0));
   return true;
 }
 
@@ -73,6 +75,60 @@ bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
 }
 
 
+///////////////////////////////////////////////////////////////////////////
+
+
+typedef STD_list<TinyVector<int,4> > QuantilIndexList;
+typedef STD_map<float, QuantilIndexList > QuantilIndexMap;
+
+
+void FilterQuantilMask::init(){
+  fraction.set_minmaxval(0.0,1.0).set_description("quantil");
+  append_arg(fraction,"fraction");
+}
+
+bool FilterQuantilMask::process(Data<float,4>& data, Protocol& prot) const {
+  Log<Filter> odinlog(c_label(),"process");
+
+  int ntotal=data.size();
+
+  float frac=fraction;
+  check_range<float>(frac,0.0,1.0);
+  int nmask=int((1.0-frac)*ntotal+0.5);
+
+  ODINLOG(odinlog,normalDebug) << "ntotal/nmask=" << ntotal << "/" << nmask << STD_endl; 
+
+  Data<float,4> mask(data.shape()); mask=0.0;
+
+  QuantilIndexMap indexmap;
+
+  for(int i=0; i<ntotal; i++) {
+    TinyVector<int,4> index=data.create_index(i);
+    indexmap[data(index)].push_back(index);
+  }
+  int nmap=indexmap.size();
+
+  ODINLOG(odinlog,normalDebug) << "ntotal/nmap=" << ntotal << "/" << nmap << STD_endl; 
+
+  QuantilIndexMap::const_iterator mapiter=indexmap.end();
+  int j=0;
+  while(j<nmask) {
+    if(mapiter==indexmap.begin()) break;
+    --mapiter;
+    const QuantilIndexList& indexlist=mapiter->second;
+    ODINLOG(odinlog,normalDebug) << "indexmap(" << mapiter->first << ")=" << indexlist.size() << STD_endl; 
+    for(QuantilIndexList::const_iterator listiter=indexlist.begin(); listiter!=indexlist.end(); ++listiter) {
+      mask(*listiter)=1.0;
+      j++;
+    }
+  }
+
+  data.reference(mask);
+
+  return true;
+}
+
+
 ///////////////////////////////////////////////////////////////////////////
 
 void FilterUseMask::init() {
