@@ -46,6 +46,20 @@ class FilterAutoMask : public FilterStep {
 };
 
 
+///////////////////////////////////////////////////////////////////////////
+
+class FilterQuantilMask : public FilterStep {
+
+  JDXfloat fraction;
+
+  STD_string label() const {return "quantilmask";}
+  STD_string description() const {return "Create mask including all voxels above the given fractional threshold";}
+  bool process(Data<float,4>& data, Protocol& prot) const;
+  FilterStep*  allocate() const {return new FilterQuantilMask();}
+  void init();
+};
+
+
 ///////////////////////////////////////////////////////////////////////////
 
 class FilterUseMask : public FilterStep {
