@@ -22,7 +22,7 @@ bool str2range(const STD_string& str, Range& range, int srcsize) {
     if(range.first()<0 || range.first()>=srcsize) result=false;
     if(range.last()<0  || range.last()>=srcsize)  result=false;
     if(!result) {
-      ODINLOG(odinlog,errorLog) << "selected " << range << " out of allowable range (0," << (srcsize-1) << ")" << STD_endl;
+      ODINLOG(odinlog,errorLog) << "selected " << range << " out of valid range (0," << (srcsize-1) << ")" << STD_endl;
     }
   }
   return result;
