@@ -6,8 +6,9 @@
 #ifdef HAVE_LIBGSL
 
 #include <gsl/gsl_multifit_nlin.h>
+#include <gsl/gsl_multimin.h>
 #include <gsl/gsl_blas.h>
-#include <tjutils/tjnumeric.h>
+
 
 // data struct to be passed through GSL functions
 struct ModelData {
@@ -201,12 +202,17 @@ bool FunctionFit::fit(const Array<float,1>& yvals,
     status = gsl_multifit_fdfsolver_iterate (gsldata->solver);
     ODINLOG(odinlog,normalDebug) << "status(fit)= " << gsl_strerror (status) << STD_endl;
     print_state (iter);
-    if (status) break;
+    if (status!=GSL_SUCCESS) break;
     status = gsl_multifit_test_delta (gsldata->solver->dx, gsldata->solver->x, tol, tol);
     ODINLOG(odinlog,normalDebug) << "status(test)= " << gsl_strerror (status) << STD_endl;
     ODINLOG(odinlog,normalDebug) << "iter/max_it= " << iter << "/" << max_it << STD_endl;
   } while (status == GSL_CONTINUE && iter < max_it);
 
+  if(status!=GSL_SUCCESS && status!=GSL_ENOPROG) { // ignoring error 'iteration is not making progress towards solution' and taking intermediate result as best fit
+    ODINLOG(odinlog,errorLog) << gsl_strerror(status) << STD_endl;
+    return false;
+  }
+
   gsl_multifit_covar (gsldata->solver->J, 0.0, gsldata->covar);
 
   // copy results
@@ -332,6 +338,44 @@ fitpar& SinusFunction::get_fitpar(unsigned int i) {
   return dummy_fitpar;
 }
 
+///////////////////////////////////////////////////////////////////
+
+void GammaVariateFunction::set_pars(float alphaval, float xmax, float ymax) {
+  A.val=ymax*pow(xmax,-alphaval)*exp(alphaval);
+  alpha.val=alphaval;
+  beta.val=xmax/alphaval;
+}
+
+float GammaVariateFunction::evaluate_f(float x) const {
+  Log<OdinData> odinlog("GammaVariateFunction","evaluate_f");
+  if(x<=0.0) {
+    ODINLOG(odinlog,errorLog) << "function not defined for x=" << x << STD_endl;
+    return 0.0;
+  }
+  return A.val*pow(x,alpha.val)*exp(-(x)/beta.val);
+}
+
+fvector GammaVariateFunction::evaluate_df(float x) const {
+  Log<OdinData> odinlog("GammaVariateFunction","evaluate_df");
+  fvector result(numof_fitpars());
+  if(x<=0.0) {
+    ODINLOG(odinlog,errorLog) << "function not defined for x=" << x << STD_endl;
+    return result;
+  }
+  result[0] = pow(x,alpha.val)*exp(-x/beta.val);
+  result[1] = A.val*pow(x,alpha.val)*exp(-x/beta.val)*log(x);
+  result[2] = A.val*pow(x,alpha.val+float(1.0))*exp(-x/beta.val)/pow(beta.val,2);
+  return result;
+}
+
+unsigned int GammaVariateFunction::numof_fitpars() const {return 3;}
+
+fitpar& GammaVariateFunction::get_fitpar(unsigned int i) {
+  if(i==0) return A;
+  if(i==1) return alpha;
+  if(i==2) return beta;
+  return dummy_fitpar;
+}
 
 ///////////////////////////////////////////////////////////////////
 
@@ -428,11 +472,125 @@ Array<float,1> LinearFunction::get_function(const Array<float,1>& xvals) const {
 const Array<float,1> LinearFunction::defaultArray;
 
 
+//////////////////////////////////////////////////////////////
+
+struct GslData4DownhillSimplex {
+  gsl_vector* x;
+  gsl_vector* ss;
+  gsl_multimin_function minex_func;
+  gsl_multimin_fminimizer* s;
+};
+
+
+double DownhillSimplex_func_f(const gsl_vector * gv, void *params) {
+
+  // get current model function
+  const  MinimizationFunction* minfunc=(const MinimizationFunction*)params;
+  unsigned int n_fitpars=minfunc->numof_fitpars();
+
+  fvector x(n_fitpars);
+  for(unsigned int i=0; i<n_fitpars; i++) x[i]=gsl_vector_get(gv, i);
+  return minfunc->evaluate(x);
+}
+
+
+DownhillSimplex::DownhillSimplex(MinimizationFunction& function) {
+  ndim=function.numof_fitpars();
+
+  gsldata=new GslData4DownhillSimplex;
+  gsldata->x = gsl_vector_alloc(ndim);
+  gsldata->ss = gsl_vector_alloc(ndim);
+
+  gsldata->minex_func.n = ndim;
+  gsldata->minex_func.f = &DownhillSimplex_func_f;
+  gsldata->minex_func.params = &function;
+
+  gsldata->s = gsl_multimin_fminimizer_alloc(gsl_multimin_fminimizer_nmsimplex2, ndim); // newer algorithm, only available in recent GSL
+//  gsldata->s = gsl_multimin_fminimizer_alloc(gsl_multimin_fminimizer_nmsimplex, ndim);
+
+}
+
+DownhillSimplex::~DownhillSimplex() {
+  // free GSL stuff
+  gsl_vector_free(gsldata->x);
+  gsl_vector_free(gsldata->ss);
+  gsl_multimin_fminimizer_free(gsldata->s);
+  delete gsldata;
+}
+
+
+fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_points, const fvector& step_size, float ftol, unsigned int nmax) {
+  Log<OdinData> odinlog("DownhillSimplex","get_minimum_parameters");
+
+  fvector result(ndim);
+
+  if(starting_points.size()!=ndim) {
+    ODINLOG(odinlog,errorLog) << "size mismatch: starting_points.size()=" << starting_points.size() << ", ndim=" << ndim << STD_endl;
+    return result;
+  }
+  if(step_size.size()!=ndim) {
+    ODINLOG(odinlog,errorLog) << "size mismatch: starting_points.size()=" << starting_points.size() << ", ndim=" << ndim << STD_endl;
+    return result;
+  }
+ 
+  for(unsigned int idim=0; idim<ndim; idim++) {
+    gsl_vector_set (gsldata->x, idim, starting_points[idim]);
+    gsl_vector_set (gsldata->ss, idim, step_size[idim]);
+  }
+
+  gsl_multimin_fminimizer_set (gsldata->s, &(gsldata->minex_func), gsldata->x, gsldata->ss);
+
+  unsigned int niterations=0;
+  int status;
+  double size;
+
+  do {
+    niterations++;
+    status = gsl_multimin_fminimizer_iterate(gsldata->s);
+           
+    if (status) break;
+     
+    size = gsl_multimin_fminimizer_size(gsldata->s);
+    status = gsl_multimin_test_size(size, ftol);
+     
+/*
+          if (status == GSL_SUCCESS)
+             {
+               printf ("converged to minimum at\n");
+             }
+     
+           printf ("%5d %10.3e %10.3e f() = %7.3f size = %.3f\n", 
+                   iter,
+                   gsl_vector_get (s->x, 0), 
+                   gsl_vector_get (s->x, 1), 
+                   s->fval, size);
+*/
+  } while (status == GSL_CONTINUE && niterations < nmax);
+
+   for(unsigned int idim=0; idim<ndim; idim++) result[idim]=gsl_vector_get(gsldata->s->x, idim);
+
+   ODINLOG(odinlog,normalDebug) << "result" << result << STD_endl;
+   ODINLOG(odinlog,normalDebug) << "min value=" << gsldata->s->fval << STD_endl;
+    
+  return result;
+}
+
 
 //////////////////////////////////////////////////////////////
 // Unit test
 
 #ifndef NO_UNIT_TEST
+
+
+class DownhillSimplexTestFunction : public MinimizationFunction {
+
+  unsigned int numof_fitpars() const {return 2;}
+  float evaluate(const fvector& xvec) const {return pow(xvec[0]-2.0,2)+pow(xvec[1]-3.0,2);}
+
+};
+
+
+
 class FunctionFitTest : public UnitTest {
 
  public:
@@ -648,7 +806,33 @@ class FunctionFitTest : public UnitTest {
       return false;
     }
 
+    
+    
+    /////////////////////////////////////////////////////
+  
+    DownhillSimplexTestFunction dstf;
+    DownhillSimplex ds(dstf);
+
+    fvector starting_points(2);
+    starting_points=0.0;
+
+    fvector step_size(2);
+    step_size=1.0;
+
+    fvector dsresult=ds.get_minimum_parameters(starting_points, step_size);
+
+    fvector dsexpected(2);
+    dsexpected[0]=2.0;
+    dsexpected[1]=3.0;
+    float maxdiff=(dsresult-dsexpected).maxabs();
+    ODINLOG(odinlog,normalDebug) << "maxdiff=" << maxdiff << STD_endl;
+    if((dsresult-dsexpected).maxabs()>1.0e-3) {
+      ODINLOG(odinlog,errorLog) << "DownhillSimplex failed, result" << dsresult << ", but expected" << dsexpected << STD_endl;
+      return false;
+    }
+
     return true;
+
   }
 
 };
