@@ -18,6 +18,7 @@
 #ifndef FITTING_H
 #define FITTING_H
 
+#include <tjutils/tjnumeric.h> // for MinimizationFunction
 #include <odindata/data.h>
 #include <odindata/linalg.h>
 #include <odindata/utils.h>
@@ -246,7 +247,7 @@ struct GaussianFunction : public ModelFunction {
   *
   * Class for fitting sinus function to a 1D curve
   *
-  * y= a*sin(m*x + c)
+  * y= A*sin(m*x + c)
   */
 struct SinusFunction : public ModelFunction {
 
@@ -263,6 +264,34 @@ struct SinusFunction : public ModelFunction {
 
 ///////////////////////////////////////////////////////////////////////
 
+
+/**
+  *
+  * Class for fitting gamma variate function to a 1D curve
+  *
+  * y= A*x^alpha*exp(-x/beta)
+  */
+struct GammaVariateFunction : public ModelFunction {
+
+/**
+  *
+  * Set parameters from a simplified set of parameters: xmax and ymax are the x- and y-values of the maximum (see Madsen, Phys. Med. Biol. 37, 1992)
+  */
+  void set_pars(float alphaval, float xmax, float ymax);
+
+  fitpar A;
+  fitpar alpha;
+  fitpar beta;
+
+  // implementing virtual functions of ModelFunction
+  float evaluate_f(float x) const;
+  fvector evaluate_df(float x) const;
+  unsigned int numof_fitpars() const;
+  fitpar& get_fitpar(unsigned int i);
+};
+
+///////////////////////////////////////////////////////////////////////
+
 /**
   *
   * Class for polynomial fitting of function
@@ -411,6 +440,45 @@ struct LinearFunction {
 
 
 
+///////////////////////////////////////////////////////////////////////
+
+class GslData4DownhillSimplex; // forward declaration
+
+/**
+  * downhill simplex optimizer
+  */
+class DownhillSimplex {
+
+ public:
+
+/**
+  * Construct downhill simplex optimizer
+  * - function: Function to evaluate/minimize
+  */
+  DownhillSimplex(MinimizationFunction& function);
+
+/**
+  * Destructor
+  */
+  ~DownhillSimplex();
+
+/**
+  * Returns parameter values which minimize function
+  * - starting_points: Starting from this initial point
+  * - step_size: The size of the initial trial steps
+  * - ftol:  Tolerannce
+  * - nmax: Max number of iterations
+  */
+  fvector get_minimum_parameters(const fvector& starting_points, const fvector& step_size, float ftol=1e-3, unsigned int nmax=1000);
+
+
+ private:
+  unsigned int ndim;
+  GslData4DownhillSimplex* gsldata;
+
+};
+
+
 ///////////////////////////////////////////////////////////////////////
 
 
