@@ -428,9 +428,8 @@ Geometry& Geometry::set_orientation(sliceOrientation orientation) {
   return *this;
 }
 
-sliceOrientation Geometry::get_orientation() const {
-  Log<Para> odinlog(this,"get_orientation");
-  dvector svec=get_sliceVector();
+sliceOrientation Geometry::get_slice_orientation(const dvector& svec) {
+  Log<Para> odinlog("Geometry","get_slice_orientation");
   sliceOrientation result=axial;
   double xabs=fabs(svec[xAxis]);
   double yabs=fabs(svec[yAxis]);
