@@ -18,6 +18,7 @@ void kSpaceCoord::reset2defaults() {
   postDiscard=0;
   concat=1;
   oversampling=1.0;
+  relcenter=0.5;
   readoutIndex=-1;
   trajIndex=-1;
   weightIndex=-1;
@@ -41,6 +42,7 @@ bool kSpaceCoord::operator == (const kSpaceCoord& ri) const {
   if(ri.postDiscard!=postDiscard) return false;
   if(ri.concat!=concat) return false;
   if(ri.oversampling!=oversampling) return false;
+  if(ri.relcenter!=relcenter) return false;
   if(ri.readoutIndex!=readoutIndex) return false;
   if(ri.trajIndex!=trajIndex) return false;
   if(ri.weightIndex!=weightIndex) return false;
@@ -61,6 +63,7 @@ bool kSpaceCoord::operator < (const kSpaceCoord& ri) const {
   if(postDiscard!=ri.postDiscard) return (postDiscard<ri.postDiscard);
   if(concat!=ri.concat) return (concat<ri.concat);
   if(oversampling!=ri.oversampling) return (oversampling<ri.oversampling);
+  if(relcenter!=ri.relcenter) return (relcenter<ri.relcenter);
   if(readoutIndex!=ri.readoutIndex) return (readoutIndex<ri.readoutIndex);
   if(trajIndex!=ri.trajIndex) return (trajIndex<ri.trajIndex);
   if(weightIndex!=ri.weightIndex) return (weightIndex<ri.weightIndex);
@@ -80,6 +83,7 @@ STD_string kSpaceCoord::print_header(const unsigned short* numof_cache) {
   result+="postDiscard,";
   result+="concat,";
   result+="oversampling,";
+  result+="relcenter,";
   result+="readoutIndex,";
   result+="trajIndex,";
   result+="weightIndex,";
@@ -105,6 +109,7 @@ STD_string kSpaceCoord::printcoord(const unsigned short* numof_cache) const {
   result+=itos(postDiscard)+tab;
   result+=itos(concat)+tab;
   result+=ftos(oversampling)+tab;
+  result+=ftos(relcenter)+tab;
   result+=itos(readoutIndex)+tab;
   result+=itos(trajIndex)+tab;
   result+=itos(weightIndex)+tab;
@@ -199,6 +204,7 @@ bool kSpaceCoord::parsecoord(const STD_string& str) {
   if(parsepos_postDiscard>=0) postDiscard=atoi(toks[parsepos_postDiscard].c_str());
   if(parsepos_concat>=0) concat=atoi(toks[parsepos_concat].c_str());
   if(parsepos_oversampling>=0) oversampling=atof(toks[parsepos_oversampling].c_str());
+  if(parsepos_relcenter>=0) relcenter=atof(toks[parsepos_relcenter].c_str());
   if(parsepos_readoutIndex>=0) readoutIndex=atoi(toks[parsepos_readoutIndex].c_str());
   if(parsepos_trajIndex>=0) trajIndex=atoi(toks[parsepos_trajIndex].c_str());
   if(parsepos_weightIndex>=0) weightIndex=atoi(toks[parsepos_weightIndex].c_str());
@@ -238,6 +244,7 @@ void kSpaceCoord::assign_parsepos(const STD_string& header) {
   max_parsepos=STD_max(max_parsepos,parsepos_postDiscard=findval(toks,"postDiscard"));
   max_parsepos=STD_max(max_parsepos,parsepos_concat=findval(toks,"concat"));
   max_parsepos=STD_max(max_parsepos,parsepos_oversampling=findval(toks,"oversampling"));
+  max_parsepos=STD_max(max_parsepos,parsepos_relcenter=findval(toks,"relcenter"));
   max_parsepos=STD_max(max_parsepos,parsepos_readoutIndex=findval(toks,"readoutIndex"));
   max_parsepos=STD_max(max_parsepos,parsepos_trajIndex=findval(toks,"trajIndex"));
   max_parsepos=STD_max(max_parsepos,parsepos_weightIndex=findval(toks,"weightIndex"));
@@ -259,6 +266,7 @@ int kSpaceCoord::parsepos_preDiscard;
 int kSpaceCoord::parsepos_postDiscard;
 int kSpaceCoord::parsepos_concat;
 int kSpaceCoord::parsepos_oversampling;
+int kSpaceCoord::parsepos_relcenter;
 int kSpaceCoord::parsepos_readoutIndex;
 int kSpaceCoord::parsepos_trajIndex;
 int kSpaceCoord::parsepos_weightIndex;
@@ -288,7 +296,7 @@ void JDXkSpaceCoords::clear() {
     }
   }
   vec_cache.clear();
-  for(unsigned int j=0; j<n_recoIndexDims; j++) numof_cache[j]=1;
+  for(int j=0; j<n_recoIndexDims; j++) numof_cache[j]=1;
   coordlist.clear();
   state=coords_in_list;
 }
@@ -305,7 +313,7 @@ JDXkSpaceCoords& JDXkSpaceCoords::append_coord(const kSpaceCoord& coord) {
 void JDXkSpaceCoords::create_vec_cache() const {
   if(state==has_vec_cache || state==has_vec_alloc) return;
 
-  for(unsigned int j=0; j<n_recoIndexDims; j++) numof_cache[j]=1;
+  for(int j=0; j<n_recoIndexDims; j++) numof_cache[j]=1;
 
   // move k-space coords from list to vector
   int adcindices_size=coordlist.size();
@@ -314,7 +322,7 @@ void JDXkSpaceCoords::create_vec_cache() const {
   for(STD_list<kSpaceCoord>::iterator it=coordlist.begin(); it!=coordlist.end(); ++it) {
     kSpaceCoord& coord=(*it);
     vec_cache[counter]=&coord;
-    for(unsigned int j=0; j<n_recoIndexDims; j++) numof_cache[j]=STD_max(numof_cache[j],(unsigned short)(coord.index[j]+1));
+    for(int j=0; j<n_recoIndexDims; j++) numof_cache[j]=STD_max(numof_cache[j],(unsigned short)(coord.index[j]+1));
     counter++;
   }
   state=has_vec_cache;
@@ -323,7 +331,9 @@ void JDXkSpaceCoords::create_vec_cache() const {
 
 bool JDXkSpaceCoords::parsevalstring (const STD_string& parstring) {
   Log<Para> odinlog(this,"parsevalstring");
+  ODINLOG(odinlog,normalDebug) << "tokenizing ..." << STD_endl;
   svector toks(tokens(parstring));
+  ODINLOG(odinlog,normalDebug) << "toks.size()=" << toks.size() << STD_endl;
   if(!toks.size()) return true;
   kSpaceCoord::assign_parsepos(toks[0]);
   unsigned int n_lines=toks.size()-1;
@@ -331,10 +341,11 @@ bool JDXkSpaceCoords::parsevalstring (const STD_string& parstring) {
   clear();
   vec_cache.resize(n_lines);
   bool result=true;
+  ODINLOG(odinlog,normalDebug) << "parsing sinle tokens ..." << STD_endl;
   for(unsigned int i=0; i<n_lines; i++) {
     vec_cache[i]=new kSpaceCoord;
     if(!vec_cache[i]->parsecoord(toks[i+1])) result=false;
-    for(unsigned int j=0; j<n_recoIndexDims; j++) numof_cache[j]=STD_max(numof_cache[j],(unsigned short)(vec_cache[i]->index[j]+1));
+    for(int j=0; j<n_recoIndexDims; j++) numof_cache[j]=STD_max(numof_cache[j],(unsigned short)(vec_cache[i]->index[j]+1));
   }
   state=has_vec_alloc;
   ODINLOG(odinlog,normalDebug) << "size()=" << size() << STD_endl;
