@@ -65,7 +65,7 @@ SeqPars& SeqPars::set_MatrixSize(direction dir,unsigned int size,parameterMode p
     case phaseDirection: MatrixSizePhase=size; MatrixSizePhase.set_parmode(parmode);break;
     case sliceDirection: MatrixSizeSlice=size; MatrixSizeSlice.set_parmode(parmode);break;
     default:
-      ODINLOG(odinlog,errorLog) << "Channel " << dir << " is not available." << STD_endl;
+      ODINLOG(odinlog,errorLog) << "Direction " << dir << " is not available." << STD_endl;
   }
   return *this;
 }
