@@ -1060,16 +1060,18 @@ GuiListView::GuiListView(QWidget *parent, const svector& column_labels, int firs
     qtrw->setColumnCount(column_labels.size());
     qtrw->setHeaderLabels(qsl);
     qtrw->setSortingEnabled(false);
-    qtrw->setMinimumHeight(min_height);
-    qtrw->setMinimumWidth(width_factor*first_column_width);
+    if(min_height>0) qtrw->setMinimumHeight(min_height);
+    if(first_column_width>0) qtrw->setMinimumWidth(width_factor*first_column_width);
     qtrw->header()->resizeSection(0, first_column_width);
   } else {
     qtw=new QTableWidget(parent);
     qtw->setColumnCount(column_labels.size());
     qtw->setHorizontalHeaderLabels(qsl);
-    qtw->setMinimumHeight(min_height);
-    qtw->setMinimumWidth(width_factor*first_column_width);
-    qtw->horizontalHeader()->resizeSection(0, first_column_width);
+    if(min_height>0) qtw->setMinimumHeight(min_height);
+    if(first_column_width>0) {
+      qtw->setMinimumWidth(width_factor*first_column_width);
+      qtw->horizontalHeader()->resizeSection(0, first_column_width);
+    }
   }
 
 #else
@@ -1175,6 +1177,9 @@ GuiListItem::GuiListItem(GuiListView *parent, const svector& column_entries, boo
     (*tablemap)[&(qtwi[0])]=this;
   }
 #else
+
+  QListViewItem* last=parent->qlv->lastItem();
+
   if(checkable) {
     qcli=new QCheckListItem (parent->qlv, column_entries[0].c_str(), QCheckListItem::CheckBox);
     qcli->setOn(initstate);
@@ -1184,6 +1189,7 @@ GuiListItem::GuiListItem(GuiListView *parent, const svector& column_entries, boo
     ODINLOG(odinlog,normalDebug) << "parent->qlv=" << parent->qlv << STD_endl;
     qlvi=new QListViewItem(parent->qlv, label[0], label[1], label[2], label[3], label[4], label[5], label[6], label[7]);
     ODINLOG(odinlog,normalDebug) << "qlvi=" << qlvi << STD_endl;
+    if(last) qlvi->moveItem(last); // append at end
     qlvi->setSelected(false);
     qlvi->setOpen(true);
     (*listmap)[qlvi]=this;
@@ -1389,7 +1395,8 @@ GuiToolButton::GuiToolButton(GuiToolBar* parent, const char** xpm, const char* l
   qtb->setToggleButton(checkable);
 #endif
   set_on(initstate);
-  set_label(label);
+  if(xpm) set_tooltip(label);
+  else set_label(label);
   sd=new SlotDispatcher(this,receiver,member);
 }
 
@@ -1427,12 +1434,15 @@ void GuiToolButton::set_enabled(bool flag) {
 void GuiToolButton::set_label(const char* text) {
 #ifdef QT_VERSION_4
   qtb->setText(text);
-  qtb->setToolTip(text);
 #else
   qtb->setTextLabel(text);
 #endif
 }
 
+void GuiToolButton::set_tooltip(const char* text) {
+  add_tooltip(qtb,text);
+}
+
 /////////////////////////////////////////////////
 
 
