@@ -21,6 +21,26 @@
 #include "step.h"
 #include "measindex.h"
 
+class RecoBladeGrid : public RecoStep {
+
+  // implementing virtual functions of RecoStep
+  STD_string label() const {return "gridblade";}
+  STD_string description() const {return "grid kspace center of single blades";}
+  bool process(RecoData& rd, RecoController& controller);
+  RecoCoord input_coord() const {return RecoCoord::coord_with_mode(RecoIndex::collected,cycle,line3d,line,readout);}
+  void modify_coord(RecoCoord& coord) const {}
+  bool query(RecoQueryContext& context);
+  RecoStep* allocate() const {return new RecoBladeGrid;}
+  void init();
+
+  JDXbool  fft;
+  JDXfilter filtermask; 
+
+  // Phase-encoding lines actually measured
+  RecoMeasIndex<line3d, RecoDim<5, line, line3d, channel, repetition, freq> > measlines;
+};
+
+//////////////////////////////////////////////////////////////
 
 class RecoCycleRot : public RecoStep {
 
@@ -76,8 +96,11 @@ class RecoBladeComb : public RecoStep {
   void init();
 
   JDXbool  keyhole;
+  JDXbool  corrweight;
   JDXfilter keyhole_filter;
+  JDXfilter kspaceweight_filter;
   JDXfloat  transition;
+  JDXfloat  kspaceweight_width;
 
   STD_map<int,KspaceTraj*> trajmap;  // caching trajectories, one for each keyhole index
   Mutex trajmutex;
