@@ -3,7 +3,8 @@
 #include "step.h"
 #include "reader.h"
 #include "measindex.h"
-#include "fieldmap.h"
+#include "fieldmap.h" // for posted_fmap_str
+#include "driftcorr.h" // for posted_drift_str
 
 
 
@@ -63,10 +64,18 @@ RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0),
   disableSliceTime.set_cmdline_option("ds").set_description("Disable slice-time correction");
   parblock.append(disableSliceTime);
 
+  disableGrappa=false;
+  disableGrappa.set_cmdline_option("dg").set_description("Disable GRAPPA interpolation");
+  parblock.append(disableGrappa);
+
   phaseCourse=false;
   phaseCourse.set_cmdline_option("pt").set_description("Combine and store phase timecourse from all channels");
   parblock.append(phaseCourse);
 
+  qcspike=false;
+  qcspike.set_cmdline_option("qs").set_description("Quality control: Check for spikes in data");
+  parblock.append(qcspike);
+
   preproc3d="null";
   preproc3d.set_cmdline_option("prp").set_description("Recipe for post processing of 3D volume before channel combining");
   parblock.append(preproc3d);
@@ -83,6 +92,13 @@ RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0),
   fieldmapFile.set_cmdline_option("fm").set_description("Load fieldmap data from this file");
   parblock.append(fieldmapFile);
 
+  driftcalcFile="";
+  driftcalcFile.set_cmdline_option("dcw").set_description("Calculate and store field drift to file with this prefix");
+  parblock.append(driftcalcFile);
+
+  driftcorrFile="";
+  driftcorrFile.set_cmdline_option("dcr").set_description("Load field drift from this file");
+  parblock.append(driftcorrFile);
 
   factory=new RecoStepFactory(&parblock);
 }
@@ -437,10 +453,12 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
 
 
 
+  STD_string driftcorrstr;
+  if(driftcorrFile!="") driftcorrstr="driftcorr | ";
 
 
   STD_string averagestr;
-  if(numof_cache[average]>1) averagestr="averagecoll | averagesum |";
+  if(numof_cache[average]>1) averagestr="averagecoll | averagesum | ";
 
 
   bool has_blade=(numof_cache[cycle]>1 && !has_traj); // Assume PROPELLER
@@ -511,30 +529,32 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
   }
 
   STD_string interpolstr;
-  bool has_grappa_template=has_templcorr_cache[grappa_template];
-  if(has_grappa_template || reduction_factor>1 || reduction_factor3d>1) {
-    STD_string redfactstr=itos(reduction_factor);
-    STD_string redfactstr3d=itos(reduction_factor3d);
-    if(has_grappa_template) {
-      if(corrstr!="") corrstr+="; ";
-      corrstr+="templtype=G {"+averagestr+adcprep+phasecorrstr+"kspace | chancoll | ";
-      if(reduction_factor>1)   corrstr+="grappaweightstempl("  +redfactstr+  ")";
-      if(reduction_factor3d>1) corrstr+="grappaweightstempl3d("+redfactstr3d+")";
-      corrstr+="}";
-    }
-    STD_string weightsstr;
-    if(!has_grappa_template) {
-      if(reduction_factor>1)   weightsstr+="grappaweights("+  redfactstr+  ") | ";
-      if(reduction_factor3d>1) weightsstr+="grappaweights3d("+redfactstr3d+") | ";
-    }
-    interpolstr+="chancoll | "+weightsstr;
+  if(!disableGrappa) {
+    bool has_grappa_template=has_templcorr_cache[grappa_template];
+    if(has_grappa_template || reduction_factor>1 || reduction_factor3d>1) {
+      STD_string redfactstr=itos(reduction_factor);
+      STD_string redfactstr3d=itos(reduction_factor3d);
+      if(has_grappa_template) {
+        if(corrstr!="") corrstr+="; ";
+        corrstr+="templtype=G {"+averagestr+adcprep+phasecorrstr+"kspace | chancoll | ";
+        if(reduction_factor>1)   corrstr+="grappaweightstempl("  +redfactstr+  ")";
+        if(reduction_factor3d>1) corrstr+="grappaweightstempl3d("+redfactstr3d+")";
+        corrstr+="}";
+      }
+      STD_string weightsstr;
+      if(!has_grappa_template) {
+        if(reduction_factor>1)   weightsstr+="grappaweights("+  redfactstr+  ") | ";
+        if(reduction_factor3d>1) weightsstr+="grappaweights3d("+redfactstr3d+") | ";
+      }
+      interpolstr+="chancoll | "+weightsstr;
 
-    STD_string keephshapestr;
-    if(has_blade) keephshapestr=",true"; // do not expand k-space to image matrix size
+      STD_string keephshapestr;
+      if(has_blade) keephshapestr=",true"; // do not expand k-space to image matrix size
 
-    if(reduction_factor>1)   interpolstr+="grappa("  +redfactstr+keephshapestr+  ") | ";
-    if(reduction_factor3d>1) interpolstr+="grappa3d("+redfactstr3d+keephshapestr+") | ";
-    interpolstr+="chansplit | ";
+      if(reduction_factor>1)   interpolstr+="grappa("  +redfactstr+keephshapestr+  ") | ";
+      if(reduction_factor3d>1) interpolstr+="grappa3d("+redfactstr3d+keephshapestr+") | ";
+      interpolstr+="chansplit | ";
+    }
   }
 
   STD_string fftstr="fft | ";
@@ -560,19 +580,21 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
   STD_string swstr;
   if(slidingWindow || (keyhole && has_blade) ) swstr="slidingwindow | ";
 
+  STD_string spikestr="";
+  if(qcspike) spikestr="qcspike | "; // insert after k-space has been collected but before interpolation
 
-  STD_string kspacestr=adcprep + phasecorrstr + "kspace | " + interpolstr;
+  STD_string kspacestr=adcprep + phasecorrstr + "kspace | " + spikestr + interpolstr;
   STD_string adcbaselinestr;
   STD_string deapodizestr;
   STD_string gridstr;
   if(has_traj) {
     adcbaselinestr="adc_baseline | ";
     if(conjPhaseFT) {
-      kspacestr="adc_weight | conjphase | "+swstr+"cyclecoll | cyclesum | ";
+      kspacestr="adc_weight | conjphase | " + spikestr + swstr + "cyclecoll | cyclesum | ";
       offsetstr="";
       fftstr="";
     } else {
-      kspacestr="grid2d | line3dcoll | "+swstr+"cyclecoll | cyclesum | ";
+      kspacestr="grid2d | line3dcoll | " + spikestr + swstr + "cyclecoll | cyclesum | ";
       if(!dumpKspace) deapodizestr="deapodize2d | ";
       gridstr="gridcut | ";
     }
@@ -638,12 +660,17 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
 
   if(numof_cache[dti]>1) pp3dpost+="dti | ";
 
-  result = averagestr + adcbaselinestr + mfreqbegin + kspacestr + bladestr + offsetstr
+  result = driftcorrstr + averagestr + adcbaselinestr + mfreqbegin + kspacestr + bladestr + offsetstr
                      + kspaceprep + fftstr + adcdeapodize + deapodizestr + gridstr + phasecoursestr + pp3dpre + chanstr
                      + freqcomb_and_oversampling + pp3dpost + maskstr
                      + "slicecoll | image | " + slicetimestr + "store";
 
-  if(corrstr!="") {
+  if(driftcalcFile!="") {
+    result= averagestr + adcbaselinestr + kspacestr + bladestr + offsetstr
+                     + kspaceprep + fftstr + adcdeapodize + deapodizestr + gridstr + oversamplingstr + " chanrepslicecoll | driftcalc | dump("+driftcalcFile+",asc)";
+  }
+
+  if(disableGrappa || corrstr!="") {
     result="switch(templtype=N { "+result+"} ; "+corrstr+")";
   }
 
@@ -947,6 +974,24 @@ bool RecoController::prepare_pipeline() {
 
   }
 
+
+  // Loading and posting field drift
+  if(driftcorrFile!="") {
+
+    announce_data(posted_drift_str);
+
+    Data<float,1> drift;
+    if(drift.autoread(driftcorrFile)<0) return false;
+    ComplexData<1> cdrift(float2real(drift));
+
+    RecoData rdfdrift;
+    rdfdrift.coord().any();
+    rdfdrift.data(Rank<1>()).reference(cdrift);
+
+    post_data(posted_drift_str, rdfdrift);
+  }
+
+
   ODINLOG(odinlog,infoLog) << "Preparing pipeline ..." << STD_endl;
   RecoQueryContext context(RecoQueryContext::prep, *this, numof_cache);
   if(!pipeline->query(context)) return false;
