@@ -174,11 +174,15 @@ class RecoController {
   JDXbool   disableHomodyne;
   JDXbool   disableMultiFreq;
   JDXbool   disableSliceTime;
+  JDXbool   disableGrappa;
   JDXbool   phaseCourse;
+  JDXbool   qcspike;
   JDXstring preproc3d;
   JDXstring postproc3d;
   JDXstring dumpRawPrefix;
   JDXstring fieldmapFile;
+  JDXstring driftcalcFile;
+  JDXstring driftcorrFile;
 
   bool execute_pipeline();
   bool prepare_pipeline();
