@@ -20,6 +20,7 @@ RecoData& RecoData::free(int dim) {
   if(dim==3) data3.free();
   if(dim==4) data4.free();
   if(dim==5) data5.free();
+  if(dim==6) data6.free();
   return *this;
 }
 
@@ -29,6 +30,7 @@ RecoData& RecoData::operator = (const RecoData& rd) {
   data3.reference(rd.data3.copy());
   data4.reference(rd.data4.copy());
   data5.reference(rd.data5.copy());
+  data6.reference(rd.data6.copy());
   return copy_meta(rd);
 }
 
