@@ -303,6 +303,10 @@ void RecoGrappa<interpolDim,orthoDim,interpolIndex,orthoIndex>::init() {
   reduction_factor.set_description("Reduction factor");
   append_arg(reduction_factor,"reduction_factor");
 
+  keep_shape=false;
+  keep_shape.set_description("Do not correct shape of interpolated k-space according to image space size");
+  append_arg(keep_shape,"keep_shape");
+
 }
 
 
@@ -317,7 +321,9 @@ bool RecoGrappa<interpolDim,orthoDim,interpolIndex,orthoIndex>::process(RecoData
 
   ODINLOG(odinlog,normalDebug) << "reduction_factor=" << reduction_factor << STD_endl;
 
-  if(!correct_shape(rd, controller)) return false; // adjust shape to account for incomplete sampling at end of k-space
+  if(!keep_shape) {
+    if(!correct_shape(rd, controller)) return false; // adjust shape to account for incomplete sampling at end of k-space
+  }
 
   ODINLOG(odinlog,normalDebug) << "Requesting weights for " << rd.coord().print() << STD_endl;
   RecoData rdweights(rd.coord());
@@ -382,7 +388,7 @@ bool RecoGrappa<interpolDim,orthoDim,interpolIndex,orthoIndex>::process(RecoData
             ivector neighboffset=next_neighbours_offset(reduction_factor, neighbours_phase, ired);
             ODINLOG(odinlog,normalDebug) << "neighboffset" << neighboffset << STD_endl;
 
-            for(int iread=0; iread<sizeRead; iread++) {
+            for(int iread=neighbours_read/2; iread<(sizeRead-neighbours_read/2); iread++) { // avoid interpolation of edges without neighbours
               for(int ichan=0; ichan<nChannels; ichan++) {
 
                 TinyVector<int,4> kspaceindex;
