@@ -38,6 +38,7 @@ class RecoGrid : public RecoStep {
   JDXbool   deapo_shift;
   JDXfilter kernel;
   JDXfloat  kernelwidth;
+  JDXfloat  gridScale;
 
   static STD_string postfix() {return itos(NDim)+"d";}
 
@@ -72,6 +73,18 @@ class RecoDeapodize : public RecoStep {
 
 };
 
+class RecoGridCut : public RecoStep {
+
+  // implementing virtual functions of RecoStep
+  STD_string label() const {return "gridcut"; }
+  STD_string description() const {return "Cut out central part of image to remove effects from gridding on a denser grid";}
+  bool process(RecoData& rd, RecoController& controller);
+  RecoCoord input_coord() const {return RecoCoord::coord_with_mode(RecoIndex::collected, line3d, line, readout);}
+  void modify_coord(RecoCoord& coord) const {}
+  RecoStep* allocate() const {return new RecoGridCut;}
+  void init() {}
+};
+
 
 #endif
 
