@@ -235,12 +235,13 @@ struct RecoCoord {
 /**
   * Convenience function: Sets specified dimensions to mode 'm'
   */
-  RecoCoord& set_mode(RecoIndex::indexMode m, recoDim d1=n_recoDims, recoDim d2=n_recoDims, recoDim d3=n_recoDims, recoDim d4=n_recoDims, recoDim d5=n_recoDims) {
+  RecoCoord& set_mode(RecoIndex::indexMode m, recoDim d1=n_recoDims, recoDim d2=n_recoDims, recoDim d3=n_recoDims, recoDim d4=n_recoDims, recoDim d5=n_recoDims, recoDim d6=n_recoDims) {
     if(d1<n_recoDims) index[d1].set_mode(m);
     if(d2<n_recoDims) index[d2].set_mode(m);
     if(d3<n_recoDims) index[d3].set_mode(m);
     if(d4<n_recoDims) index[d4].set_mode(m);
     if(d5<n_recoDims) index[d5].set_mode(m);
+    if(d6<n_recoDims) index[d6].set_mode(m);
     return *this;
   }
 
@@ -248,9 +249,9 @@ struct RecoCoord {
 /**
   * Convenience function: Returns coordinate with specified dimensions set to mode 'm'
   */
-  static RecoCoord coord_with_mode(RecoIndex::indexMode m, recoDim d1=n_recoDims, recoDim d2=n_recoDims, recoDim d3=n_recoDims, recoDim d4=n_recoDims, recoDim d5=n_recoDims) {
+  static RecoCoord coord_with_mode(RecoIndex::indexMode m, recoDim d1=n_recoDims, recoDim d2=n_recoDims, recoDim d3=n_recoDims, recoDim d4=n_recoDims, recoDim d5=n_recoDims, recoDim d6=n_recoDims) {
     RecoCoord result;
-    result.set_mode(m,d1,d2,d3,d4,d5);
+    result.set_mode(m,d1,d2,d3,d4,d5,d6);
     return result;
   }
 
@@ -365,7 +366,7 @@ typedef STD_map<RecoCoord, UInt> CoordCountMap;
 /**
   * Helper template to define a set of 'Ndim' dimensions using default arguments for unused dimensions.
   */
-template<unsigned int Ndim, recoDim d1=n_recoDims, recoDim d2=n_recoDims, recoDim d3=n_recoDims, recoDim d4=n_recoDims, recoDim d5=n_recoDims>
+template<unsigned int Ndim, recoDim d1=n_recoDims, recoDim d2=n_recoDims, recoDim d3=n_recoDims, recoDim d4=n_recoDims, recoDim d5=n_recoDims, recoDim d6=n_recoDims>
 struct RecoDim {
 
 /**
@@ -376,12 +377,12 @@ struct RecoDim {
 /**
   * Returns coordinate with specified dimensions set to mode 'm'.
   */
-  static RecoCoord preset_coord(RecoIndex::indexMode m) {return RecoCoord::coord_with_mode(m, d1, d2, d3, d4, d5);}
+  static RecoCoord preset_coord(RecoIndex::indexMode m) {return RecoCoord::coord_with_mode(m, d1, d2, d3, d4, d5, d6);}
 
 /**
   * Sets specified dimensions in coordinate 'coord' to mode 'm'.
   */
-  static void modify(RecoIndex::indexMode m, RecoCoord& coord) {coord.set_mode(m, d1, d2, d3, d4, d5);}
+  static void modify(RecoIndex::indexMode m, RecoCoord& coord) {coord.set_mode(m, d1, d2, d3, d4, d5, d6);}
 
 /**
   * Creates 'Ndim' dimensional index vector in specified dimensions using coordinate 'coord'.
@@ -393,6 +394,7 @@ struct RecoDim {
     if(d3!=n_recoDims) {index(idim)=coord.index[d3]; idim++;}
     if(d4!=n_recoDims) {index(idim)=coord.index[d4]; idim++;}
     if(d5!=n_recoDims) {index(idim)=coord.index[d5]; idim++;}
+    if(d6!=n_recoDims) {index(idim)=coord.index[d6]; idim++;}
   }
 
 /**
@@ -405,6 +407,7 @@ struct RecoDim {
     if(d3!=n_recoDims) {shape(idim)=coord.numof(d3); idim++;}
     if(d4!=n_recoDims) {shape(idim)=coord.numof(d4); idim++;}
     if(d5!=n_recoDims) {shape(idim)=coord.numof(d5); idim++;}
+    if(d6!=n_recoDims) {shape(idim)=coord.numof(d6); idim++;}
   }
 
 
@@ -418,6 +421,7 @@ struct RecoDim {
     if(d3!=n_recoDims) {coord.index[d3]=index(idim); idim++;}
     if(d4!=n_recoDims) {coord.index[d4]=index(idim); idim++;}
     if(d5!=n_recoDims) {coord.index[d5]=index(idim); idim++;}
+    if(d6!=n_recoDims) {coord.index[d6]=index(idim); idim++;}
   }
 
 };
