@@ -10,6 +10,7 @@
 #include "adc.h"
 #include "dump.h"
 #include "dti.h"
+#include "driftcorr.h"
 #include "epinavcorr.h"
 #include "expfit.h"
 #include "fieldmap.h"
@@ -21,12 +22,13 @@
 #include "homodyne.h"
 #include "messer.h"
 #include "mip.h"
+#include "multifreq.h"
 #include "offset.h"
 #include "oversampling.h"
 #include "phasecorr.h"
 #include "phasecourse.h"
 #include "pilot.h"
-#include "multifreq.h"
+#include "qualitycontrol.h"
 #include "refgain.h"
 #include "slicetime.h"
 #include "slidingwindow.h"
@@ -113,12 +115,15 @@ void RecoStep::create_templates(STD_list<RecoStep*>& result) {
   result.push_back(new RecoCollector<1, RecoDim<1, readout>,                      1, RecoDim<1, average>, true >      ("averagecoll"));
   result.push_back(new RecoCollector<1, RecoDim<1, readout>,                      1, RecoDim<1, echo>, true >         ("echocoll"));
   result.push_back(new RecoCollector<3, RecoDim<3, line3d, line, readout>,        2, RecoDim<2, channel, repetition>, true > ("chanrepcoll"));
+  result.push_back(new RecoCollector<3, RecoDim<3, line3d, line, readout>,        3, RecoDim<3, channel, repetition, slice>, true > ("chanrepslicecoll"));
   result.push_back(new RecoConjPhaseFT());
   result.push_back(new RecoCycleRot());
   result.push_back(new RecoDeapodize<1>());
   result.push_back(new RecoDeapodize<2>());
   result.push_back(new RecoDump());
   result.push_back(new RecoDTI());
+  result.push_back(new RecoDriftCalc());
+  result.push_back(new RecoDriftCorr());
   result.push_back(new RecoEpiNavScan());
   result.push_back(new RecoEpiNavCorr());
   result.push_back(new RecoExpFit());
@@ -153,6 +158,7 @@ void RecoStep::create_templates(STD_list<RecoStep*>& result) {
   result.push_back(new RecoPhaseCourse());
   result.push_back(new RecoPilot());
   result.push_back(new RecoPost());
+  result.push_back(new RecoQualityControlSpike());
   result.push_back(new RecoReal());
   result.push_back(new RecoMagn());
   result.push_back(new RecoRefGain());
