@@ -2,8 +2,9 @@
 
 #include "seqplatform.h"
 
-
-
+#ifndef __DBL_EPSILON__
+#define __DBL_EPSILON__ 1.e-38
+#endif
 ////////////////////////////////////////////////////
 // adiabatic shapes:
 
@@ -133,7 +134,7 @@ public:
 
         slope=80;
         slope.set_minmaxval ( 0,150 ).set_description ( "Exponential factor in Fermi function: influences the slope of the ramps" );
-        append_member ( slope,"Slope" );
+        append_member ( slope,"slope" );
 
 
     }
