@@ -117,6 +117,14 @@ class SeqAcqInterface : public virtual SeqFreqChanInterface {
   virtual SeqAcqInterface& set_template_type(templateType type)  {if(marshall) marshall->set_template_type(type); return set_default_reco_index(templtype,type);}
 
 
+/**
+  * Specifies whether the data points should be reversed, only relevant
+  * for automatic reconstruction
+  */
+  virtual SeqAcqInterface& set_reflect_flag(bool flag)  {if(marshall) marshall->set_reflect_flag(flag); else marshall_error(); return *this;}
+
+
+
  protected:
   SeqAcqInterface() : marshall(0) {}
   virtual ~SeqAcqInterface() {}
@@ -253,19 +261,12 @@ class SeqAcq : public virtual SeqAcqInterface, public SeqObjBase, public SeqFreq
   SeqAcq& operator = (const SeqAcq& sa);
 
 
-
-/**
-  * Specifies whether the data points should be reversed, only relevant
-  * for automatic reconstruction
-  */
-  SeqAcq& set_reflect_flag(bool flag) {reflect_flag=flag; return *this;}
-
-
 /**
   * Specifies a an explicit k-space Trajectory for this ADC (for automatic reconstruction)
   */
   void set_kspace_traj(const farray& kspaceTraj);
 
+
 /**
   * Specifies a complex vector which is is used to weight each point in this ADC (for automatic reconstruction)
   */
@@ -296,6 +297,7 @@ class SeqAcq : public virtual SeqAcqInterface, public SeqObjBase, public SeqFreq
   SeqAcqInterface& set_readout_shape(const fvector& shape, unsigned int dstsize);
   SeqAcqInterface& set_reco_vector(recoDim dim, const SeqVector& vec, const dvector& valvec=dvector());
   SeqAcqInterface& set_default_reco_index(recoDim dim, unsigned int index);
+  SeqAcqInterface& set_reflect_flag(bool flag) {reflect_flag=flag; return *this;}
 
 
   // overwriting virtual functions of SeqTreeObj
