@@ -419,7 +419,7 @@ SeqAcqEPI::SeqAcqEPI(const STD_string& object_label, double sweepwidth,
                      unsigned int shots, unsigned int reduction, float os_factor, const STD_string& nucleus,
                      const dvector& phaselist, const dvector& freqlist,
                      rampType rampmode, bool ramp_sampling, float ramp_steepness,
-                     float fourier_factor, unsigned int echo_pairs)
+                     float fourier_factor, unsigned int echo_pairs, bool invert_partial_fourier)
   : SeqObjBase(object_label), driver(object_label) {
 
   Log<Seq> odinlog(this,"SeqAcqEPI(...)");
@@ -460,8 +460,15 @@ SeqAcqEPI::SeqAcqEPI(const STD_string& object_label, double sweepwidth,
   float kspace_part=1.0-fourier_factor;
   if(kspace_part<0.0) kspace_part=0.0;
   if(kspace_part>1.0) kspace_part=1.0;
-  float k_indep_phase_min=-0.5*kspace_part*k_indep_phase;
-  float k_indep_phase_max=0.5*k_indep_phase;
+  float k_indep_phase_min;
+  float k_indep_phase_max;
+  if (invert_partial_fourier) {
+    k_indep_phase_min=-0.5*k_indep_phase;
+    k_indep_phase_max=0.5*kspace_part*k_indep_phase;
+  } else {
+    k_indep_phase_min=-0.5*kspace_part*k_indep_phase;
+    k_indep_phase_max=0.5*k_indep_phase;
+  }
 
   int phasenpts=(unsigned int)(float(phasesize_cache)*(0.5*kspace_part+0.5));
   int startindex_phase=phasesize_cache-phasenpts;
