@@ -220,7 +220,7 @@ class SeqAcqEPI : public SeqObjBase, public virtual SeqAcqInterface, public virt
             unsigned int shots=1, unsigned int reduction=1, float os_factor=1.0, const STD_string& nucleus="",
             const dvector& phaselist=0, const dvector& freqlist=0,
             rampType rampmode = linear, bool ramp_sampling=false, float ramp_steepness=1.0,
-            float fourier_factor=0.0, unsigned int echo_pairs=0);
+            float fourier_factor=0.0, unsigned int echo_pairs=0, bool invert_partial_fourier=false);
 
 
 
