@@ -62,6 +62,9 @@ class SeqGradEcho : public SeqObjList, public virtual SeqGradInterface, public v
   * - reduction:    Reduction factor for parallel imaging (sparsely sampled k-space)
   * - acl_bands:    Number of autocalibration bands (bunch of adjacent lines between actual k-space lines) for GRAPPA
   * - balanced:     Whether rephasers (+ exc dephaser) should be added after acquisition, suitable for SSFP sequences
+  * - partial_fourier_phase: The amount of partial Fourier undersampling in phase encoding direction (0=no undersampling, 1=half fourier)
+  * - partial_fourier_read: The amount of partial Fourier undersampling  in readout direction (0=no undersampling, 1=half fourier)
+  * - partial_fourier_read_at_end: If set to 'true', partial Fourier will omit data at the end of the readout
   * - os_factor:    The oversampling factor, os_factor=1 means no oversampling
   * - nucleus:      The nucleus to observe
   */
@@ -69,7 +72,8 @@ class SeqGradEcho : public SeqObjList, public virtual SeqGradInterface, public v
               double sweepwidth, unsigned int readnpts, float FOVread,
               unsigned int phasenpts, float FOVphase, encodingScheme scheme=linearEncoding,
               reorderScheme reorder=noReorder, unsigned int nsegments=1, unsigned int reduction=1, unsigned int acl_bands=DEFAULT_ACL_BANDS,
-              bool balanced=false, float patial_fourier=0.0, float os_factor=1.0, const STD_string& nucleus="");
+              bool balanced=false, float partial_fourier_phase=0.0, float partial_fourier_read=0.0, bool partial_fourier_read_at_end=false,
+              float os_factor=1.0, const STD_string& nucleus="");
 
 
 /**
@@ -85,6 +89,9 @@ class SeqGradEcho : public SeqObjList, public virtual SeqGradInterface, public v
   * - reduction:    Reduction factor for parallel imaging (sparsely sampled k-space), the factor applies to both phase-encoding directions
   * - acl_bands:    Number of autocalibration bands (bunch of adjacent lines between actual k-space lines) for GRAPPA
   * - balanced:     Whether rephasers (+ exc dephaser) should be added after acquisition, suitable for SSFP sequences
+  * - partial_fourier_phase: The amount of partial Fourier undersampling in phase encoding direction (0=no undersampling, 1=half fourier)
+  * - partial_fourier_read: The amount of partial Fourier undersampling  in readout direction (0=no undersampling, 1=half fourier)
+  * - partial_fourier_read_at_end: If set to 'true', partial Fourier will omit data at the end of the readout
   * - os_factor:    The oversampling factor, os_factor=1 means no oversampling
   * - nucleus:      The nucleus to observe
   */
@@ -92,7 +99,8 @@ class SeqGradEcho : public SeqObjList, public virtual SeqGradInterface, public v
               unsigned int readnpts, float FOVread, unsigned int phasenpts, float FOVphase, unsigned int slicenpts, float FOVslice,
               SeqPulsar& exc, double sweepwidth,
               unsigned int reduction=1, unsigned int acl_bands=DEFAULT_ACL_BANDS,
-              bool balanced=false, float patial_fourier=0.0, float os_factor=1.0, const STD_string& nucleus="");
+              bool balanced=false, float partial_fourier_phase=0.0, float partial_fourier_read=0.0, bool partial_fourier_read_at_end=false,
+              float os_factor=1.0, const STD_string& nucleus="");
 
 
 /**
