@@ -49,14 +49,14 @@ class SeqGradPhaseEnc : public SeqGradVectorPulse {
   * - nsegments:    The number of segments for segmented reordering
   * - reduction:    Reduction factor for parallel imaging (sparsely sampled k-space)
   * - acl_bands:    Number of autocalibration bands (bunch of adjacent lines between actual k-space lines) for GRAPPA
-  * - patial_fourier: The amount of partial Fourier undersampling (0=no undersampling, 1=half fourier)
+  * - partial_fourier: The amount of partial Fourier undersampling (0=no undersampling, 1=half fourier)
   * - nucleus:      The nucleus this object should be calculated for
   */
   SeqGradPhaseEnc(const STD_string& object_label, unsigned int nsteps,
                   float fov, direction gradchannel, float gradstrength,
                   encodingScheme scheme=linearEncoding, reorderScheme reorder=noReorder,
                   unsigned int nsegments=1, unsigned int reduction=1, unsigned int acl_bands=DEFAULT_ACL_BANDS,
-                  float patial_fourier=0.0, const STD_string& nucleus="");
+                  float partial_fourier=0.0, const STD_string& nucleus="");
 
 /**
   * Constructs a phase encoding gradient labeled 'object_label' with the following properties:
@@ -69,14 +69,14 @@ class SeqGradPhaseEnc : public SeqGradVectorPulse {
   * - nsegments:    The number of segments for segmented reordering
   * - reduction:    Reduction factor for parallel imaging (sparsely sampled k-space)
   * - acl_bands:    Number of autocalibration bands (bunch of adjacent lines between actual k-space lines) for GRAPPA
-  * - patial_fourier: The amount of partial Fourier undersampling (0=no undersampling, 1=half fourier)
+  * - partial_fourier: The amount of partial Fourier undersampling (0=no undersampling, 1=half fourier)
   * - nucleus:      The nucleus this object should be calculated for
   */
   SeqGradPhaseEnc(const STD_string& object_label, unsigned int nsteps,
                   float fov, float gradduration, direction gradchannel,
                   encodingScheme scheme=linearEncoding, reorderScheme reorder=noReorder,
                   unsigned int nsegments=1, unsigned int reduction=1, unsigned int acl_bands=DEFAULT_ACL_BANDS,
-                  float patial_fourier=0.0, const STD_string& nucleus="");
+                  float partial_fourier=0.0, const STD_string& nucleus="");
 
 
 /**
@@ -96,7 +96,7 @@ class SeqGradPhaseEnc : public SeqGradVectorPulse {
 
 
  private:
-  void init_encoding(unsigned int nsteps,encodingScheme scheme, reorderScheme reorder, unsigned int nsegments, unsigned int reduction, unsigned int acl_bands, float patial_fourier);
+  void init_encoding(unsigned int nsteps,encodingScheme scheme, reorderScheme reorder, unsigned int nsegments, unsigned int reduction, unsigned int acl_bands, float partial_fourier);
 
 };
 
@@ -126,14 +126,14 @@ class SeqGradPhaseEncFlowComp : public SeqGradChanList {
   * - nsegments:    The number of segments for segmented reordering
   * - reduction:    Reduction factor for parallel imaging (sparsely sampled k-space)
   * - acl_bands:    Number of autocalibration bands (bunch of adjacent lines between actual k-space lines) for GRAPPA
-  * - patial_fourier: The amount of partial Fourier undersampling (0=no undersampling, 1=half fourier)
+  * - partial_fourier: The amount of partial Fourier undersampling (0=no undersampling, 1=half fourier)
   * - nucleus:      The nucleus this object should be calculated for
   */
   SeqGradPhaseEncFlowComp(const STD_string& object_label, double t0, unsigned int nsteps,
                   float fov, direction gradchannel, float gradstrength,
                   encodingScheme scheme=linearEncoding, reorderScheme reorder=noReorder,
                   unsigned int nsegments=1, unsigned int reduction=1, unsigned int acl_bands=DEFAULT_ACL_BANDS,
-                  float patial_fourier=0.0, const STD_string& nucleus="");
+                  float partial_fourier=0.0, const STD_string& nucleus="");
 
 
 /**
