@@ -110,7 +110,7 @@ class SeqSimAbstract : public virtual SeqClass {
   * - Iterative simulation by simulate() using a structure with piece-wise constant fields.
   * - Finish simulation by calling finalize_simulation().
   */
-class SeqSimMagsi : public JcampDxBlock, public ThreadedLoop<SeqSimInterval,cvector>, public virtual SeqSimAbstract {
+class SeqSimMagsi : public JcampDxBlock, public ThreadedLoop<SeqSimInterval,cvector,int>, public virtual SeqSimAbstract {
 
 
  public:
@@ -216,7 +216,7 @@ class SeqSimMagsi : public JcampDxBlock, public ThreadedLoop<SeqSimInterval,cvec
   void finalize_simulation();
 
   // implementing virtual functions of ThreadedLoop
-  bool kernel(const SeqSimInterval& simvals, cvector& signal, unsigned int begin, unsigned int end);
+  bool kernel(const SeqSimInterval& simvals, cvector& signal, int&, unsigned int begin, unsigned int end);
 
  private:
   friend class SeqTimecourse;
@@ -324,14 +324,14 @@ class SeqSimMagsi : public JcampDxBlock, public ThreadedLoop<SeqSimInterval,cvec
   *
   * Monte-Carlo Simulator for diffusional averaging
   */
-class SeqSimMonteCarlo : public virtual SeqSimAbstract {
+class SeqSimMonteCarlo : public ThreadedLoop<SeqSimInterval,cvector,RandomDist>, public virtual SeqSimAbstract {
 
  public:
 
   /**
-  * Constructs a simulator labeled 'object_label' to simulate 'nparticles' diffusion trajectories.
+  * Constructs a simulator labeled 'object_label' to simulate 'nparticles' diffusion trajectories using 'nthreads' threads.
   */
-  SeqSimMonteCarlo(const STD_string& label="unnamedSeqSimMonteCarlo", unsigned int nparticles=10000);
+  SeqSimMonteCarlo(const STD_string& label="unnamedSeqSimMonteCarlo", unsigned int nparticles=10000, unsigned int nthreads=1);
 
 /**
   * Copy constructor
@@ -343,31 +343,40 @@ class SeqSimMonteCarlo : public virtual SeqSimAbstract {
   */
   SeqSimMonteCarlo& operator = (const SeqSimMonteCarlo& ssmc);
 
+  
+/**
+  * Get spatial distribution of particles after simulation
+  */
+  farray get_spatial_dist() const;
+
 
   // implementing virtual functions of SeqSimAbstract
   void prepare_simulation(const Sample& sample, CoilSensitivity* transmit_coil=0, CoilSensitivity* receive_coil=0, ProgressMeter* progmeter=0);
   cvector simulate(const SeqSimInterval& simvals, double gamma);
   void finalize_simulation();
 
+  // implementing virtual functions of ThreadedLoop
+  bool kernel(const SeqSimInterval& simvals, cvector& signal, RandomDist& local_rng, unsigned int begin, unsigned int end);
 
  private:
   struct Particle {
-    float xpos, ypos, zpos;
+    float pos[3];
     float Mx, My, Mz;
   };
 
   void common_init();
   void clear_cache();
 
-  unsigned int linear_index(float xpos, float ypos, float zpos) const;
+  unsigned int linear_index(const float pos[3]) const;
 
   STD_vector<Particle> particle;
+  unsigned int numof_threads;
 
   RandomDist rng; // seed only once per simulator
 
-  unsigned int xsize;
-  unsigned int ysize;
-  unsigned int zsize;
+  double gamma_cache;
+
+  unsigned int size_cache[3];
 
   // use raw pointers to avoid slower []-operator of STD_vector
   float* Dcoeff_cache;
@@ -376,9 +385,7 @@ class SeqSimMonteCarlo : public virtual SeqSimAbstract {
   float* R2map_cache;
   float* spinDensity_cache;
 
-  float xpixelspacing_cache;
-  float ypixelspacing_cache;
-  float zpixelspacing_cache;
+  float pixelspacing_cache[3];
   float B0_ppm_cache;
 
 
