@@ -137,10 +137,11 @@ class SeqTreeObj; //forward declaration
   * This enum is used to specify the behaviour for a call to query:
   * - count_acqs: Count the number of acquisition objects
   * - checkoccur: Check the occurence of a particular sequence object in this branch of the tree
+  * - check_acq_iter: Check for an iterator in subtree which is relevant for reco indicies
   * - tag_toplevel_reploop: Identify and tag outermost repetition loop
   * - display_tree: Display sequence tree
   */
-enum queryAction {count_acqs, checkoccur, tag_toplevel_reploop, display_tree};
+enum queryAction {count_acqs, checkoccur, check_acq_iter, tag_toplevel_reploop, display_tree};
 
 /**
   * Structure that holds the context the sequence tree is (recursively) queried with
@@ -148,6 +149,7 @@ enum queryAction {count_acqs, checkoccur, tag_toplevel_reploop, display_tree};
 struct queryContext {
   queryContext() : action(count_acqs), numof_acqs(0),
   checkoccur_sto(0), checkoccur_result(false),
+  check_acq_iter_result(false),
   tree_display(0), parentnode(0), treelevel(0),
   repetitions_prot(0) {}
 
@@ -161,6 +163,8 @@ struct queryContext {
   const SeqTreeObj* checkoccur_sto;
   bool checkoccur_result;
 
+  bool check_acq_iter_result;
+  
   // stuff for action 'display_tree'
   SeqTreeCallbackAbstract* tree_display;
   const SeqTreeObj* parentnode;
