@@ -65,10 +65,14 @@ class SeqVecIter : public SeqCounter, public SeqObjBase {
   double get_duration() const;
   unsigned int event(eventContext& context) const;
   STD_string get_properties() const;
+  void query(queryContext& context) const;
+  RecoValList get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const;
 
 
  private:
 
+  bool is_acq_iterator() const;
+   
   // overwriting virtual functions from SeqClass
   bool prep();
 
