@@ -19,14 +19,6 @@ private:
   JDXfloat FWbVal;
   JDXbool  FieldMap;
 
-/*
-  JDXdouble ZoomPulsDur;
-  JDXint    ZoomPulses;
-  JDXfloat  ZoomTransWidth;
-*/
-
-//  JDXdouble InversionTime;
-
   JDXdoubleArr TEs;
 
   // sequence objects which are the elementary objects
@@ -123,18 +115,7 @@ private:
 
   SeqFieldMap fmapscan;
 
-/*
-  SeqPulsar inv;
-  SeqDelay  invdelay; 
-*/
 
-/*
-  SeqPulsar  zoomsat;
-  SeqGradConstPulse     zoomspoiler;
-  SeqGradTrapezParallel zoomcrusher;
-  SeqObjLoop zoomloop;
-  SeqVecIter zoomiter;
-*/
 
 public:
 
@@ -159,7 +140,7 @@ void method_pars_init() {
   NumOfEchoes.set_description("Number of echoes per period");
   append_parameter(NumOfEchoes,"NumOfEchoes");
 
-  SEAcquisition=false;
+  SEAcquisition=true;
   SEAcquisition.set_description("Sample the spin echo directly with the last EPI");
   append_parameter(SEAcquisition,"SEAcquisition");
 
@@ -200,29 +181,7 @@ void method_pars_init() {
   fmapscan.init("fmapscan");
   append_parameter(fmapscan.get_parblock(),"FieldMapPars");
 
-/*
-  InversionTime=0.0;
-  InversionTime.set_minmaxval(0.0,10000.0);
-  InversionTime.set_unit(ODIN_TIME_UNIT);
-  InversionTime.set_description("If non-zero, perform inversion prior to excitation with this interval between both");
-  append_parameter(InversionTime,"InversionTime");
-*/
 
-/*
-  ZoomPulsDur=12.0;
-  ZoomPulsDur.set_unit(ODIN_TIME_UNIT);
-  ZoomPulsDur.set_description("Duration for zoom saturation pulse");
-  append_parameter(ZoomPulsDur,"ZoomPulsDur");
-
-  ZoomPulses=0;
-  ZoomPulses.set_description("Number of consecutive zoom saturation pulses");
-  append_parameter(ZoomPulses,"ZoomPulses");
-
-  ZoomTransWidth=10.0;
-  ZoomTransWidth.set_unit(ODIN_SPAT_UNIT);
-  ZoomTransWidth.set_description("Transition width at edges of zoom saturation");
-  append_parameter(ZoomTransWidth,"ZoomTransWidth");
-*/
 
   TEs.resize(2*NumOfEchoes);
   TEs.set_description("Echo times");
@@ -261,38 +220,6 @@ void method_seq_init() {
   fatsat=SeqSat("fatsat",fat);
 
 
-  // saturation of out-of-FOV area
-/*
-  float allFOV=220.0;
-  float zoomFOV=geometryInfo->get_FOV(phaseDirection);
-  float satthick=allFOV-zoomFOV;
-  float offset=geometryInfo->get_offset(phaseDirection)-0.5*zoomFOV-0.5*satthick+0.5*ZoomTransWidth;
-  ODINLOG(odinlog,normalDebug) << "zoomFOV/satthick/offset=" << zoomFOV << "/" << satthick << "/" << offset << STD_endl;
-
-  zoomsat=SeqPulsarSinc("zoomsat",satthick,false,ZoomPulsDur,90.0,ZoomTransWidth,int(ZoomPulsDur*100+0.5));
-  zoomsat.set_freqoffset( systemInfo->get_gamma() * zoomsat.get_strength() / (2.0*PII) * offset );
-  zoomsat.set_pulse_type(saturation);
-
-  RotMatrix satrot;
-
-  satrot[1][1]=0.0; satrot[1][2]=1.0;
-  satrot[2][1]=1.0; satrot[2][2]=0.0;
-  zoomsat.set_gradrotmatrix(satrot);
-
-  zoomsat.set_phasespoiling();
-  zoomiter=SeqVecIter("zoomiter");
-  zoomiter.add_vector(zoomsat.get_phaselist_vector());
-*/
-
-/*
-  inv=SeqPulsar("inv",false,false);
-  inv.set_dim_mode(zeroDeeMode);
-  inv.set_Tp(10.0);
-  inv.resize(500);
-  inv.set_shape("Wurst(10,20)");  // bandwidth ~ 10kHz
-  inv.set_pulse_type(inversion);
-  inv.refresh(); // because it's non-interactive
-*/
 
   //////////////// EPI-Readout: //////////////////////////////
 
@@ -454,7 +381,6 @@ void method_seq_init() {
   // TR delay
   trdelay=SeqDelay("trdelay");
 
-//  invdelay=SeqDelay("invdelay");
 
   //////////////// Spoiler Gradient: //////////////////////////////
 
@@ -464,7 +390,6 @@ void method_seq_init() {
 
   spoiler=SeqGradConstPulse("spoiler",sliceDirection,spoiler_strength,spoiler_dur);
 
-//  zoomspoiler=SeqGradConstPulse("zoomspoiler",readDirection,spoiler_strength,0.5*spoiler_dur);
 
   //////////////// Crusher Gradient: //////////////////////////////
 
@@ -474,7 +399,6 @@ void method_seq_init() {
 
   crusherdelay=SeqDelay("crusherdelay",1.0); // Small delay to avoid gradient-induced stimulation
 
-//  zoomcrusher=SeqGradTrapezParallel("zoomcrusher",spoiler_integral,spoiler_integral,spoiler_integral, spoiler_strength);
 
   //////////////// Flow Weighting: //////////////////////////////
 
@@ -522,12 +446,10 @@ void method_seq_init() {
 
   //////////////// Build the sequence: //////////////////////////////
 
-//  if(InversionTime>0.0) preppart += inv + crusher + invdelay;
 
   // add fat saturation to template and repetitions
   if(FatSaturation) preppart += fatsat;
 
-//  if(ZoomPulses>0) preppart += zoomloop(  zoomsat + zoomspoiler + zoomiter )[ZoomPulses] + zoomcrusher + crusherdelay;
 
   if(fMRITrigger) slicepart += trigger;
 
@@ -665,14 +587,6 @@ void method_rels() {
   Log<Seq> odinlog(this,"method_rels");
 
 
-/*
-  if(InversionTime>0.0) {
-    invdelay=0.0;
-    float minti=preppart.get_duration() - inv.get_magnetic_center() + exc.get_magnetic_center();
-    invdelay=InversionTime-minti;
-  }
-*/
-
   double TEexc= exc.get_duration() - exc.get_magnetic_center() + fwpart.get_duration();
   ODINLOG(odinlog,significantDebug) << "TEexc=" << TEexc << STD_endl;
 
