@@ -453,10 +453,10 @@ class TestEventThread2 : public Thread {
 
 //////////////////////////////////////////////
 
-class ThreadedLoopTest : public ThreadedLoop<STD_string,STD_string> {
+class ThreadedLoopTest : public ThreadedLoop<STD_string,STD_string,int> {
 
  private:
-  bool kernel(const STD_string& in, STD_string& out, unsigned int begin, unsigned int end) {
+  bool kernel(const STD_string& in, STD_string& out, int&, unsigned int begin, unsigned int end) {
     out="";
     for(unsigned int i=begin; i<end; i++) {
       out+=in;
